@@ -20,15 +20,17 @@ from swiftclient.client import ClientException
 from trove.common import cfg
 from trove.common import exception
 from trove.db.models import DatabaseModelBase
+from trove.datastore import models as datastore_models
 from trove.openstack.common import log as logging
 from trove.taskmanager import api
 from trove.common.remote import create_swift_client
 from trove.common import utils
 from trove.quota.quota import run_with_quotas
+from trove.openstack.common.gettextutils import _
+
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
-SWIFT_CONTAINER = CONF.backup_swift_container
 
 
 class BackupState(object):
@@ -78,7 +80,11 @@ class Backup(object):
             cls.validate_can_perform_action(
                 instance_model, 'backup_create')
             cls.verify_swift_auth_token(context)
+            if instance_model.cluster_id is not None:
+                raise exception.ClusterInstanceOperationNotSupported()
 
+            ds = instance_model.datastore
+            ds_version = instance_model.datastore_version
             parent = None
             if parent_id:
                 # Look up the parent info or fail early if not found or if
@@ -95,9 +101,11 @@ class Backup(object):
                                           state=BackupState.NEW,
                                           instance_id=instance_id,
                                           parent_id=parent_id,
+                                          datastore_version_id=ds_version.id,
                                           deleted=False)
             except exception.InvalidModelError as ex:
-                LOG.exception("Unable to create Backup record:")
+                LOG.exception(_("Unable to create backup record for "
+                                "instance: %s"), instance_id)
                 raise exception.BackupCreationError(str(ex))
 
             backup_info = {'id': db_info.id,
@@ -107,6 +115,8 @@ class Backup(object):
                            'backup_type': db_info.backup_type,
                            'checksum': db_info.checksum,
                            'parent': parent,
+                           'datastore': ds.name,
+                           'datastore_version': ds_version.name,
                            }
             api.API(context).create_backup(backup_info, instance_id)
             return db_info
@@ -169,16 +179,23 @@ class Backup(object):
         return query.all(), marker
 
     @classmethod
-    def list(cls, context):
+    def list(cls, context, datastore=None):
         """
         list all live Backups belong to given tenant
         :param cls:
         :param context: tenant_id included
+        :param datastore: datastore to filter by
         :return:
         """
         query = DBBackup.query()
-        query = query.filter_by(tenant_id=context.tenant,
-                                deleted=False)
+        filters = [DBBackup.tenant_id == context.tenant,
+                   DBBackup.deleted == 0]
+        if datastore:
+            ds = datastore_models.Datastore.load(datastore)
+            filters.append(datastore_models.DBDatastoreVersion.
+                           datastore_id == ds.id)
+            query = query.join(datastore_models.DBDatastoreVersion)
+        query = query.filter(*filters)
         return cls._paginate(context, query)
 
     @classmethod
@@ -190,8 +207,13 @@ class Backup(object):
         :return:
         """
         query = DBBackup.query()
-        query = query.filter_by(instance_id=instance_id,
-                                deleted=False)
+        if context.is_admin:
+            query = query.filter_by(instance_id=instance_id,
+                                    deleted=False)
+        else:
+            query = query.filter_by(instance_id=instance_id,
+                                    tenant_id=context.tenant,
+                                    deleted=False)
         return cls._paginate(context, query)
 
     @classmethod
@@ -223,9 +245,8 @@ class Backup(object):
         def _delete_resources():
             backup = cls.get_by_id(context, backup_id)
             if backup.is_running:
-                msg = ("Backup %s cannot be delete because it is running." %
-                       backup_id)
-                raise exception.UnprocessableEntity(msg)
+                msg = _("Backup %s cannot be deleted because it is running.")
+                raise exception.UnprocessableEntity(msg % backup_id)
             cls.verify_swift_auth_token(context)
             api.API(context).delete_backup(backup_id)
 
@@ -247,11 +268,12 @@ def persisted_models():
 
 
 class DBBackup(DatabaseModelBase):
-    """A table for Backup records"""
+    """A table for Backup records."""
     _data_fields = ['id', 'name', 'description', 'location', 'backup_type',
                     'size', 'tenant_id', 'state', 'instance_id',
                     'checksum', 'backup_timestamp', 'deleted', 'created',
-                    'updated', 'deleted_at', 'parent_id']
+                    'updated', 'deleted_at', 'parent_id',
+                    'datastore_version_id']
     preserve_on_delete = True
 
     @property
@@ -267,21 +289,35 @@ class DBBackup(DatabaseModelBase):
         if self.location:
             last_slash = self.location.rfind("/")
             if last_slash < 0:
-                raise ValueError("Bad location for backup object.")
+                raise ValueError(_("Bad location for backup object: %s")
+                                 % self.location)
             return self.location[last_slash + 1:]
         else:
             return None
 
+    @property
+    def datastore(self):
+        if self.datastore_version_id:
+            return datastore_models.Datastore.load(
+                self.datastore_version.datastore_id)
+
+    @property
+    def datastore_version(self):
+        if self.datastore_version_id:
+            return datastore_models.DatastoreVersion.load_by_uuid(
+                self.datastore_version_id)
+
     def check_swift_object_exist(self, context, verify_checksum=False):
         try:
             parts = self.location.split('/')
             obj = parts[-1]
             container = parts[-2]
             client = create_swift_client(context)
-            LOG.info(_("Checking if backup exist in '%s'") % self.location)
+            LOG.debug("Checking if backup exists in %s" % self.location)
             resp = client.head_object(container, obj)
             if verify_checksum:
-                LOG.info(_("Checking if backup checksum matches swift."))
+                LOG.debug("Checking if backup checksum matches swift "
+                          "for backup %s" % self.id)
                 # swift returns etag in double quotes
                 # e.g. '"dc3b0827f276d8d78312992cc60c2c3f"'
                 swift_checksum = resp['etag'].strip('"')
