@@ -15,6 +15,7 @@
 import routes
 
 from trove.common import wsgi
+from trove.cluster.service import ClusterController
 from trove.configuration.service import ConfigurationsController
 from trove.configuration.service import ParametersController
 from trove.flavor.service import FlavorController
@@ -26,11 +27,12 @@ from trove.datastore.service import DatastoreController
 
 
 class API(wsgi.Router):
-    """API"""
+    """Defines the API routes."""
     def __init__(self):
         mapper = routes.Mapper()
         super(API, self).__init__(mapper)
         self._instance_router(mapper)
+        self._cluster_router(mapper)
         self._datastore_router(mapper)
         self._flavor_router(mapper)
         self._versions_router(mapper)
@@ -81,6 +83,10 @@ class API(wsgi.Router):
                        controller=instance_resource,
                        action="update",
                        conditions={'method': ['PUT']})
+        mapper.connect("/{tenant_id}/instances/{id}",
+                       controller=instance_resource,
+                       action="edit",
+                       conditions={'method': ['PATCH']})
         mapper.connect("/{tenant_id}/instances/{id}",
                        controller=instance_resource,
                        action="delete",
@@ -94,6 +100,34 @@ class API(wsgi.Router):
                        action="configuration",
                        conditions={'method': ['GET']})
 
+    def _cluster_router(self, mapper):
+        cluster_resource = ClusterController().create_resource()
+        mapper.connect("/{tenant_id}/clusters",
+                       controller=cluster_resource,
+                       action="index",
+                       conditions={'method': ['GET']})
+        mapper.connect("/{tenant_id}/clusters/{id}",
+                       controller=cluster_resource,
+                       action="show",
+                       conditions={'method': ['GET']})
+        mapper.connect("/{tenant_id}/clusters",
+                       controller=cluster_resource,
+                       action="create",
+                       conditions={'method': ['POST']})
+        mapper.connect("/{tenant_id}/clusters/{id}",
+                       controller=cluster_resource,
+                       action="action",
+                       conditions={'method': ['POST']})
+        mapper.connect("/{tenant_id}/clusters/{cluster_id}/instances/"
+                       "{instance_id}",
+                       controller=cluster_resource,
+                       action="show_instance",
+                       conditions={'method': ['GET']})
+        mapper.connect("/{tenant_id}/clusters/{id}",
+                       controller=cluster_resource,
+                       action="delete",
+                       conditions={'method': ['DELETE']})
+
     def _flavor_router(self, mapper):
         flavor_resource = FlavorController().create_resource()
         mapper.connect("/{tenant_id}/flavors",
