@@ -24,6 +24,31 @@ url_ref = {
                '|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
 }
 
+boolean_string = {
+    "type": "integer",
+    "minimum": 0,
+    "maximum": 1
+}
+
+configuration_data_types = {
+    "type": "string",
+    "minLength": 1,
+    "pattern": "integer|string"
+}
+
+configuration_integer_size = {
+    "type": "string",
+    "maxLength": 40,
+    "pattern": "[0-9]+"
+}
+
+configuration_non_empty_string = {
+    "type": "string",
+    "minLength": 1,
+    "maxLength": 128,
+    "pattern": "^.*[0-9a-zA-Z]+.*$"
+}
+
 flavorref = {
     'oneOf': [
         url_ref,
@@ -180,6 +205,55 @@ configuration_id = {
     ]
 }
 
+cluster = {
+    "create": {
+        "type": "object",
+        "required": ["cluster"],
+        "additionalProperties": True,
+        "properties": {
+            "cluster": {
+                "type": "object",
+                "required": ["name", "datastore", "instances"],
+                "additionalProperties": True,
+                "properties": {
+                    "name": non_empty_string,
+                    "datastore": {
+                        "type": "object",
+                        "required": ["type", "version"],
+                        "additionalProperties": True,
+                        "properties": {
+                            "type": non_empty_string,
+                            "version": non_empty_string
+                        }
+                    },
+                    "instances": {
+                        "type": "array",
+                        "items": {
+                            "type": "object",
+                            "required": ["flavorRef"],
+                            "additionalProperties": True,
+                            "properties": {
+                                "flavorRef": flavorref,
+                                "volume": volume
+                            }
+                        }
+                    }
+                }
+            }
+        }
+    },
+    "add_shard": {
+        "type": "object",
+        "required": ["add_shard"],
+        "additionalProperties": True,
+        "properties": {
+            "add_shard": {
+                "type": "object"
+            }
+        }
+    }
+}
+
 instance = {
     "create": {
         "type": "object",
@@ -188,8 +262,7 @@ instance = {
         "properties": {
             "instance": {
                 "type": "object",
-                "required": ["name", "flavorRef",
-                             "volume" if CONF.trove_volume_support else None],
+                "required": ["name", "flavorRef"],
                 "additionalProperties": True,
                 "properties": {
                     "name": non_empty_string,
@@ -220,6 +293,20 @@ instance = {
             }
         }
     },
+    "edit": {
+        "name": "instance:edit",
+        "type": "object",
+        "required": ["instance"],
+        "properties": {
+            "instance": {
+                "type": "object",
+                "required": [],
+                "properties": {
+                    "slave_of": {},
+                }
+            }
+        }
+    },
     "action": {
         "resize": {
             "volume": {
@@ -266,6 +353,21 @@ instance = {
     }
 }
 
+mgmt_cluster = {
+    "action": {
+        'reset-task': {
+            "type": "object",
+            "required": ["reset-task"],
+            "additionalProperties": True,
+            "properties": {
+                "reset-task": {
+                    "type": "object"
+                }
+            }
+        }
+    }
+}
+
 mgmt_instance = {
     "action": {
         'migrate': {
@@ -425,6 +527,45 @@ configuration = {
     }
 }
 
+mgmt_configuration = {
+    "create": {
+        "name": "configuration_parameter:create",
+        "type": "object",
+        "required": ["configuration-parameter"],
+        "properties": {
+            "configuration-parameter": {
+                "type": "object",
+                "required": ["name", "restart_required", "data_type"],
+                "properties": {
+                    "name": configuration_non_empty_string,
+                    "data_type": configuration_data_types,
+                    "restart_required": boolean_string,
+                    "max_size": configuration_integer_size,
+                    "min_size": configuration_integer_size,
+                }
+            }
+        }
+    },
+    "update": {
+        "name": "configuration_parameter:update",
+        "type": "object",
+        "required": ["configuration-parameter"],
+        "properties": {
+            "configuration-parameter": {
+                "type": "object",
+                "required": ["name", "restart_required", "data_type"],
+                "properties": {
+                    "name": configuration_non_empty_string,
+                    "data_type": configuration_data_types,
+                    "restart_required": boolean_string,
+                    "max_size": configuration_integer_size,
+                    "min_size": configuration_integer_size,
+                }
+            }
+        }
+    },
+}
+
 account = {
     'create': {
         "type": "object",
@@ -436,3 +577,23 @@ account = {
         }
     }
 }
+
+upgrade = {
+    "create": {
+        "type": "object",
+        "required": ["upgrade"],
+        "additionalProperties": True,
+        "properties": {
+            "upgrade": {
+                "type": "object",
+                "required": [],
+                "additionalProperties": True,
+                "properties": {
+                    "instance_version": non_empty_string,
+                    "location": non_empty_string,
+                    "metadata": {}
+                }
+            }
+        }
+    }
+}
