@@ -15,11 +15,14 @@
 #    under the License.
 
 import jinja2
+from oslo.config import cfg as oslo_config
+
 from trove.common import cfg
 from trove.common import configurations
 from trove.common import exception
 from trove.common import utils
 from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
@@ -38,36 +41,53 @@ class SingleInstanceConfigTemplate(object):
         rendering on the guest
     """
 
-    template_name = "%s/config.template"
+    template_name = "config.template"
 
-    def __init__(self, datastore_manager, flavor_dict, instance_id):
+    def __init__(self, datastore_version, flavor_dict, instance_id):
         """Constructor
 
-        :param datastore_manager: The datastore manager.
-        :type name: str.
+        :param datastore_version: The datastore version.
+        :type datastore_version: DatastoreVersion
         :param flavor_dict: dict containing flavor details for use in jinja.
         :type flavor_dict: dict.
         :param instance_id: trove instance id
-        :type: instance_id: str
+        :type instance_id: str
 
         """
         self.flavor_dict = flavor_dict
-        template_filename = self.template_name % datastore_manager
-        self.template = ENV.get_template(template_filename)
-        self.datastore_manager = datastore_manager
+        self.datastore_version = datastore_version
+        # TODO(tim.simpson): The current definition of datastore_version is a
+        #                    bit iffy and I believe will change soon, so I'm
+        #                    creating a dictionary here for jinja to consume
+        #                    rather than pass in the datastore version object.
+        self.datastore_dict = {
+            'name': self.datastore_version.datastore_name,
+            'manager': self.datastore_version.manager,
+            'version': self.datastore_version.name,
+        }
         self.instance_id = instance_id
 
+    def get_template(self):
+        patterns = ['{name}/{version}/{template_name}',
+                    '{name}/{template_name}',
+                    '{manager}/{template_name}']
+        context = self.datastore_dict.copy()
+        context['template_name'] = self.template_name
+        names = [name.format(**context) for name in patterns]
+        return ENV.select_template(names)
+
     def render(self, **kwargs):
         """Renders the jinja template
 
         :returns: str -- The rendered configuration file
 
         """
-        template = ENV.get_template(self.template_name %
-                                    self.datastore_manager)
+        template = self.get_template()
         server_id = self._calculate_unique_id()
         self.config_contents = template.render(
-            flavor=self.flavor_dict, server_id=server_id, **kwargs)
+            flavor=self.flavor_dict,
+            datastore=self.datastore_dict,
+            server_id=server_id, **kwargs)
         return self.config_contents
 
     def render_dict(self):
@@ -76,10 +96,10 @@ class SingleInstanceConfigTemplate(object):
         to apply the default configuration dynamically.
         """
         config = self.render()
-        cfg_parser = SERVICE_PARSERS.get(self.datastore_manager)
+        cfg_parser = SERVICE_PARSERS.get(self.datastore_version.manager)
         if not cfg_parser:
             raise exception.NoConfigParserFound(
-                datastore_manager=self.datastore_manager)
+                datastore_manager=self.datastore_version.manager)
         return cfg_parser(config).parse()
 
     def _calculate_unique_id(self):
@@ -92,15 +112,34 @@ class SingleInstanceConfigTemplate(object):
 
 
 class OverrideConfigTemplate(SingleInstanceConfigTemplate):
-    template_name = "%s/override.config.template"
+    template_name = "override.config.template"
+
+
+def _validate_datastore(datastore_manager):
+    try:
+        CONF.get(datastore_manager)
+    except oslo_config.NoSuchOptError:
+        raise exception.InvalidDatastoreManager(
+            datastore_manager=datastore_manager)
 
 
 def load_heat_template(datastore_manager):
-    template_filename = "%s/heat.template" % datastore_manager
+    patterns = ["%s/heat.template" % datastore_manager,
+                "default.heat.template"]
+    _validate_datastore(datastore_manager)
     try:
-        template_obj = ENV.get_template(template_filename)
+        template_obj = ENV.select_template(patterns)
         return template_obj
     except jinja2.TemplateNotFound:
-        msg = "Missing heat template for %s" % datastore_manager
+        msg = _("Missing heat template for %(s_datastore_manager)s.") % (
+            {"s_datastore_manager": datastore_manager})
         LOG.error(msg)
         raise exception.TroveError(msg)
+
+
+class ReplicaSourceConfigTemplate(SingleInstanceConfigTemplate):
+    template_name = "replica_source.config.template"
+
+
+class ReplicaConfigTemplate(SingleInstanceConfigTemplate):
+    template_name = "replica.config.template"
