@@ -14,18 +14,18 @@
 #    under the License.
 
 import json
-
-from oslo_log import log as logging
+from datetime import datetime
 
 from trove.common import cfg
 from trove.common import exception
-from trove.common.exception import ModelNotFoundError
-from trove.common.i18n import _
-from trove.common import timeutils
 from trove.common import utils
+from trove.common.exception import ModelNotFoundError
 from trove.datastore import models as dstore_models
 from trove.db import get_db_api
 from trove.db import models as dbmodels
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
+from trove.taskmanager import api as task_api
 
 
 CONF = cfg.CONF
@@ -39,23 +39,25 @@ class Configurations(object):
     @staticmethod
     def load(context):
         if context is None:
-            raise TypeError(_("Argument context not defined."))
+            raise TypeError("Argument context not defined.")
         elif id is None:
-            raise TypeError(_("Argument is not defined."))
+            raise TypeError("Argument is not defined.")
 
         if context.is_admin:
             db_info = DBConfiguration.find_all(deleted=False)
             if db_info.count() == 0:
                 LOG.debug("No configurations found for admin user")
         else:
-            db_info = DBConfiguration.find_all(tenant_id=context.project_id,
+            db_info = DBConfiguration.find_all(tenant_id=context.tenant,
                                                deleted=False)
             if db_info.count() == 0:
-                LOG.debug("No configurations found for tenant %s",
-                          context.project_id)
+                LOG.debug("No configurations found for tenant %s"
+                          % context.tenant)
+
+        limit = int(context.limit or Configurations.DEFAULT_LIMIT)
+        if limit > Configurations.DEFAULT_LIMIT:
+            limit = Configurations.DEFAULT_LIMIT
 
-        limit = utils.pagination_limit(context.limit,
-                                       Configurations.DEFAULT_LIMIT)
         data_view = DBConfiguration.find_by_pagination('configurations',
                                                        db_info,
                                                        "foo",
@@ -90,10 +92,10 @@ class Configuration(object):
 
     @staticmethod
     def create_items(cfg_id, values):
-        LOG.debug("Saving configuration values for %(id)s - "
-                  "values: %(values)s", {'id': cfg_id, 'values': values})
+        LOG.debug("Saving configuration values for %s - "
+                  "values: %s" % (cfg_id, values))
         config_items = []
-        for key, val in values.items():
+        for key, val in values.iteritems():
             config_item = DBConfigurationParameter.create(
                 configuration_id=cfg_id,
                 configuration_key=key,
@@ -103,7 +105,7 @@ class Configuration(object):
 
     @staticmethod
     def delete(context, group):
-        deleted_at = timeutils.utcnow()
+        deleted_at = datetime.utcnow()
         Configuration.remove_all_items(context, group.id, deleted_at)
         group.deleted = True
         group.deleted_at = deleted_at
@@ -113,7 +115,7 @@ class Configuration(object):
     def remove_all_items(context, id, deleted_at):
         items = DBConfigurationParameter.find_all(configuration_id=id,
                                                   deleted=False).all()
-        LOG.debug("Removing all configuration values for %s", id)
+        LOG.debug("Removing all configuration values for %s" % id)
         for item in items:
             item.deleted = True
             item.deleted_at = deleted_at
@@ -133,7 +135,7 @@ class Configuration(object):
                 return DBConfiguration.find_by(id=id, deleted=False)
             else:
                 return DBConfiguration.find_by(id=id,
-                                               tenant_id=context.project_id,
+                                               tenant_id=context.tenant,
                                                deleted=False)
         except ModelNotFoundError:
             msg = _("Configuration group with ID %s could not be found.") % id
@@ -187,15 +189,15 @@ class Configuration(object):
             self.configuration_id)
         config_items = Configuration.load_items(self.context,
                                                 id=self.configuration_id)
-        LOG.debug("config_items: %s", config_items)
+        LOG.debug("config_items: %s" % config_items)
         detail_list = DatastoreConfigurationParameters.load_parameters(
-            datastore_v.id)
+            datastore_v.id, show_deleted=True)
 
         for i in config_items:
-            LOG.debug("config item: %s", i)
+            LOG.debug("config item: %s" % i)
             details = Configuration.find_parameter_details(
                 i.configuration_key, detail_list)
-            LOG.debug("parameter details: %s", details)
+            LOG.debug("parameter details: %s" % details)
             if not details:
                 raise exception.NotFound(uuid=i.configuration_key)
             if bool(details.restart_required):
@@ -203,32 +205,27 @@ class Configuration(object):
         return False
 
     @staticmethod
-    def save(configuration, configuration_items):
+    def save(context, configuration, configuration_items, instances):
         DBConfiguration.save(configuration)
         for item in configuration_items:
             item["deleted_at"] = None
             DBConfigurationParameter.save(item)
 
-    @staticmethod
-    def find(context, configuration_id, datastore_version_id):
-        try:
-            info = Configuration.load(context, configuration_id)
-            if (info.datastore_version_id == datastore_version_id):
-                return Configuration(context, configuration_id)
-        except exception.ModelNotFoundError:
-            raise exception.NotFound(
-                message='Configuration group id: %s could not be found.'
-                % configuration_id)
+        items = Configuration.load_items(context, configuration.id)
 
-        raise exception.ConfigurationDatastoreNotMatchInstance(
-            config_datastore_version=info.datastore_version_id,
-            instance_datastore_version=datastore_version_id)
+        for instance in instances:
+            LOG.debug("Configuration %s being applied to "
+                      "instance: %s" % (configuration.id, instance.id))
+            overrides = {}
+            for i in items:
+                overrides[i.configuration_key] = i.configuration_value
+
+            task_api.API(context).update_overrides(instance.id, overrides)
 
 
 class DBConfiguration(dbmodels.DatabaseModelBase):
     _data_fields = ['name', 'description', 'tenant_id', 'datastore_version_id',
                     'deleted', 'deleted_at', 'created', 'updated']
-    _table_name = 'configurations'
 
     @property
     def datastore(self):
@@ -246,11 +243,9 @@ class DBConfiguration(dbmodels.DatabaseModelBase):
 
 
 class DBConfigurationParameter(dbmodels.DatabaseModelBase):
-    _auto_generated_attrs = []
     _data_fields = ['configuration_id', 'configuration_key',
                     'configuration_value', 'deleted',
                     'deleted_at']
-    _table_name = 'configuration_parameters'
 
     def __hash__(self):
         return self.configuration_key.__hash__()
@@ -258,6 +253,7 @@ class DBConfigurationParameter(dbmodels.DatabaseModelBase):
 
 class DBDatastoreConfigurationParameters(dbmodels.DatabaseModelBase):
     """Model for storing the configuration parameters on a datastore."""
+    _auto_generated_attrs = ['id']
     _data_fields = [
         'name',
         'datastore_version_id',
@@ -265,12 +261,14 @@ class DBDatastoreConfigurationParameters(dbmodels.DatabaseModelBase):
         'max_size',
         'min_size',
         'data_type',
+        'deleted',
+        'deleted_at',
     ]
     _table_name = "datastore_configuration_parameters"
+    preserve_on_delete = True
 
 
 class DatastoreConfigurationParameters(object):
-
     def __init__(self, db_info):
         self.db_info = db_info
 
@@ -285,12 +283,22 @@ class DatastoreConfigurationParameters(object):
         ds_v_id = kwargs.get('datastore_version_id')
         config_param_name = kwargs.get('name')
         try:
-            DatastoreConfigurationParameters.load_parameter_by_name(
+            param = DatastoreConfigurationParameters.load_parameter_by_name(
                 ds_v_id,
-                config_param_name)
-            raise exception.ConfigurationParameterAlreadyExists(
-                parameter_name=config_param_name,
-                datastore_version=ds_v_id)
+                config_param_name,
+                show_deleted=True)
+            if param.deleted == 1:
+                param.restart_required = kwargs.get('restart_required')
+                param.data_type = kwargs.get('data_type')
+                param.max_size = kwargs.get('max_size')
+                param.min_size = kwargs.get('min_size')
+                param.deleted = 0
+                param.save()
+                return param
+            else:
+                raise exception.ConfigurationParameterAlreadyExists(
+                    parameter_name=config_param_name,
+                    datastore_version=ds_v_id)
         except exception.NotFound:
             pass
         config_param = DBDatastoreConfigurationParameters.create(
@@ -301,29 +309,54 @@ class DatastoreConfigurationParameters(object):
     def delete(version_id, config_param_name):
         config_param = DatastoreConfigurationParameters.load_parameter_by_name(
             version_id, config_param_name)
-        config_param.delete()
+        config_param.deleted = True
+        config_param.deleted_at = datetime.utcnow()
+        config_param.save()
 
     @classmethod
-    def load_parameters(cls, datastore_version_id):
-        return DBDatastoreConfigurationParameters.find_all(
-            datastore_version_id=datastore_version_id)
-
-    @classmethod
-    def load_parameter(cls, config_id):
+    def load_parameters(cls, datastore_version_id, show_deleted=False):
         try:
-            return DBDatastoreConfigurationParameters.find_by(
-                id=config_id, deleted=False
-            )
+            if show_deleted:
+                return DBDatastoreConfigurationParameters.find_all(
+                    datastore_version_id=datastore_version_id
+                )
+            else:
+                return DBDatastoreConfigurationParameters.find_all(
+                    datastore_version_id=datastore_version_id,
+                    deleted=False
+                )
+        except exception.NotFound:
+            raise exception.NotFound(uuid=datastore_version_id)
+
+    @classmethod
+    def load_parameter(cls, config_id, show_deleted=False):
+        try:
+            if show_deleted:
+                return DBDatastoreConfigurationParameters.find_by(
+                    id=config_id
+                )
+            else:
+                return DBDatastoreConfigurationParameters.find_by(
+                    id=config_id, deleted=False
+                )
         except exception.NotFound:
             raise exception.NotFound(uuid=config_id)
 
     @classmethod
-    def load_parameter_by_name(cls, datastore_version_id, config_param_name):
+    def load_parameter_by_name(cls, datastore_version_id, config_param_name,
+                               show_deleted=False):
         try:
-            return DBDatastoreConfigurationParameters.find_by(
-                datastore_version_id=datastore_version_id,
-                name=config_param_name
-            )
+            if show_deleted:
+                return DBDatastoreConfigurationParameters.find_by(
+                    datastore_version_id=datastore_version_id,
+                    name=config_param_name
+                )
+            else:
+                return DBDatastoreConfigurationParameters.find_by(
+                    datastore_version_id=datastore_version_id,
+                    name=config_param_name,
+                    deleted=False
+                )
         except exception.NotFound:
             raise exception.NotFound(uuid=config_param_name)
 
@@ -339,7 +372,7 @@ def create_or_update_datastore_configuration_parameter(name,
         datastore_version_id)
     try:
         config = DatastoreConfigurationParameters.load_parameter_by_name(
-            datastore_version_id, name)
+            datastore_version_id, name, show_deleted=True)
         config.restart_required = restart_required
         config.max_size = max_size
         config.min_size = min_size
@@ -354,16 +387,17 @@ def create_or_update_datastore_configuration_parameter(name,
             data_type=data_type,
             max_size=max_size,
             min_size=min_size,
+            deleted=False,
         )
         get_db_api().save(config)
 
 
-def load_datastore_configuration_parameters(datastore, datastore_version,
-                                            config_file, version_number=None):
+def load_datastore_configuration_parameters(datastore,
+                                            datastore_version,
+                                            config_file):
     get_db_api().configure_db(CONF)
     (ds, ds_v) = dstore_models.get_datastore_version(
-        type=datastore, version=datastore_version, return_inactive=True,
-        version_number=version_number)
+        type=datastore, version=datastore_version)
     with open(config_file) as f:
         config = json.load(f)
         for param in config['configuration-parameters']:
@@ -377,21 +411,9 @@ def load_datastore_configuration_parameters(datastore, datastore_version,
             )
 
 
-def remove_datastore_configuration_parameters(datastore, datastore_version,
-                                              version_number=None):
-    get_db_api().configure_db(CONF)
-    (ds, ds_version) = dstore_models.get_datastore_version(
-        type=datastore, version=datastore_version, return_inactive=True,
-        version_number=version_number)
-    db_params = DatastoreConfigurationParameters.load_parameters(ds_version.id)
-    for db_param in db_params:
-        db_param.delete()
-
-
 def persisted_models():
     return {
         'configurations': DBConfiguration,
         'configuration_parameters': DBConfigurationParameter,
-        'datastore_configuration_parameters':
-            DBDatastoreConfigurationParameters,
+        'datastore_configuration_parameters': DBDatastoreConfigurationParameters,  # noqa
     }
