@@ -15,13 +15,13 @@
 
 from datetime import datetime
 from trove.common import cfg
-from trove.common import configurations
 from trove.common import exception
 from trove.common import pagination
 from trove.common import wsgi
 from trove.configuration import models
 from trove.configuration import views
-from trove.configuration.models import ConfigurationParameter
+from trove.configuration.models import DBConfigurationParameter
+from trove.configuration.models import DatastoreConfigurationParameters
 from trove.datastore import models as ds_models
 from trove.openstack.common import log as logging
 from trove.openstack.common.gettextutils import _
@@ -46,10 +46,17 @@ class ConfigurationsController(wsgi.Controller):
         return wsgi.Result(paged.data(), 200)
 
     def show(self, req, tenant_id, id):
+        LOG.debug("Showing configuration group %(id)s on tenant %(tenant)s"
+                  % {"tenant": tenant_id, "id": id})
         context = req.environ[wsgi.CONTEXT_KEY]
         configuration = models.Configuration.load(context, id)
         configuration_items = models.Configuration.load_items(context, id)
 
+        configuration.instance_count = instances_models.DBInstance.find_all(
+            tenant_id=context.tenant,
+            configuration_id=configuration.id,
+            deleted=False).count()
+
         return wsgi.Result(views.DetailedConfigurationView(
                            configuration,
                            configuration_items).data(), 200)
@@ -74,13 +81,17 @@ class ConfigurationsController(wsgi.Controller):
         return wsgi.Result(paged.data(), 200)
 
     def create(self, req, body, tenant_id):
-        LOG.debug(_("req : '%s'\n\n") % req)
-        LOG.debug(_("body : '%s'\n\n") % req)
+        LOG.debug("req : '%s'\n\n" % req)
+        LOG.debug("body : '%s'\n\n" % req)
 
         name = body['configuration']['name']
         description = body['configuration'].get('description')
         values = body['configuration']['values']
 
+        msg = _("Creating configuration group on tenant "
+                "%(tenant_id)s with name: %(cfg_name)s")
+        LOG.info(msg % {"tenant_id": tenant_id, "cfg_name": name})
+
         datastore_args = body['configuration'].get('datastore', {})
         datastore, datastore_version = (
             ds_models.get_datastore_version(**datastore_args))
@@ -90,10 +101,10 @@ class ConfigurationsController(wsgi.Controller):
             # validate that the values passed in are permitted by the operator.
             ConfigurationsController._validate_configuration(
                 body['configuration']['values'],
-                datastore_manager=datastore_version.manager)
+                datastore_version=datastore_version)
 
             for k, v in values.iteritems():
-                configItems.append(ConfigurationParameter(
+                configItems.append(DBConfigurationParameter(
                     configuration_key=k,
                     configuration_value=v))
 
@@ -107,6 +118,10 @@ class ConfigurationsController(wsgi.Controller):
         return wsgi.Result(view_data.data(), 200)
 
     def delete(self, req, tenant_id, id):
+        msg = _("Deleting configuration group %(cfg_id)s on tenant: "
+                "%(tenant_id)s")
+        LOG.info(msg % {"tenant_id": tenant_id, "cfg_id": id})
+
         context = req.environ[wsgi.CONTEXT_KEY]
         group = models.Configuration.load(context, id)
         instances = instances_models.DBInstance.find_all(
@@ -119,13 +134,18 @@ class ConfigurationsController(wsgi.Controller):
         return wsgi.Result(None, 202)
 
     def update(self, req, body, tenant_id, id):
-        LOG.info(_("Updating configuration for tenant id %s") % tenant_id)
+        msg = _("Updating configuration group %(cfg_id)s for tenant "
+                "id %(tenant_id)s")
+        LOG.info(msg % {"tenant_id": tenant_id, "cfg_id": id})
+
         context = req.environ[wsgi.CONTEXT_KEY]
         group = models.Configuration.load(context, id)
         instances = instances_models.DBInstance.find_all(
             tenant_id=context.tenant,
             configuration_id=id,
             deleted=False).all()
+        LOG.debug("Loaded instances for configuration group %s on "
+                  "tenant %s: %s" % (id, tenant_id, instances))
 
         # if name/description are provided in the request body, update the
         # model with these values as well.
@@ -138,7 +158,6 @@ class ConfigurationsController(wsgi.Controller):
         items = self._configuration_items_list(group, body['configuration'])
         deleted_at = datetime.utcnow()
         models.Configuration.remove_all_items(context, group.id, deleted_at)
-        LOG.info(_("loaded configuration instances: %s") % instances)
         models.Configuration.save(context, group, items, instances)
         return wsgi.Result(None, 202)
 
@@ -149,7 +168,8 @@ class ConfigurationsController(wsgi.Controller):
             tenant_id=context.tenant,
             configuration_id=id,
             deleted=False).all()
-        LOG.info(_("loaded configuration instances: %s") % instances)
+        LOG.debug("Loaded instances for configuration group %s on "
+                  "tenant %s: %s" % (id, tenant_id, instances))
         items = self._configuration_items_list(group, body['configuration'])
         models.Configuration.save(context, group, items, instances)
 
@@ -157,50 +177,45 @@ class ConfigurationsController(wsgi.Controller):
         ds_version_id = group.datastore_version_id
         ds_version = ds_models.DatastoreVersion.load_by_uuid(ds_version_id)
         items = []
-        LOG.info(_("loaded configuration group: %s") % group)
         if 'values' in configuration:
             # validate that the values passed in are permitted by the operator.
             ConfigurationsController._validate_configuration(
-                configuration['values'], datastore_manager=ds_version.manager)
+                configuration['values'], datastore_version=ds_version)
             for k, v in configuration['values'].iteritems():
-                items.append(ConfigurationParameter(configuration_id=group.id,
-                                                    configuration_key=k,
-                                                    configuration_value=v,
-                                                    deleted=False))
+                items.append(DBConfigurationParameter(
+                    configuration_id=group.id,
+                    configuration_key=k,
+                    configuration_value=v,
+                    deleted=False))
         return items
 
     @staticmethod
-    def _validate_configuration(values, datastore_manager=None):
-        rules = configurations.get_validation_rules(
-            datastore_manager=datastore_manager)
-
+    def _validate_configuration(values, datastore_version=None):
         LOG.info(_("Validating configuration values"))
         for k, v in values.iteritems():
-            # get the validation rule dictionary, which will ensure there is a
-            # rule for the given key name. An exception will be thrown if no
-            # valid rule is located.
-            rule = ConfigurationsController._get_item(
-                k, rules['configuration-parameters'])
+            rule = DatastoreConfigurationParameters.load_parameter_by_name(
+                datastore_version.id, k)
 
-            if rule.get('deleted_at'):
-                raise exception.ConfigurationParameterDeleted(
-                    parameter_name=rule.get('name'),
-                    parameter_deleted_at=rule.get('deleted_at'))
+            if not rule or rule.deleted:
+                output = {"key": k}
+                msg = _("The parameter provided for the configuration "
+                        "%(key)s is not available.") % output
+                raise exception.UnprocessableEntity(message=msg)
 
             # type checking
-            valueType = rule.get('type')
+            value_type = rule.data_type
 
             if not isinstance(v, ConfigurationsController._find_type(
-                    valueType)):
-                output = {"key": k, "type": valueType}
+                    value_type)):
+                output = {"key": k, "type": value_type}
                 msg = _("The value provided for the configuration "
                         "parameter %(key)s is not of type %(type)s.") % output
                 raise exception.UnprocessableEntity(message=msg)
 
             # integer min/max checking
-            if isinstance(v, int) and not isinstance(v, bool):
+            if isinstance(v, (int, long)) and not isinstance(v, bool):
                 try:
-                    min_value = int(rule.get('min'))
+                    min_value = int(rule.min_size)
                 except ValueError:
                     raise exception.TroveError(_(
                         "Invalid or unsupported min value defined in the "
@@ -214,7 +229,7 @@ class ConfigurationsController(wsgi.Controller):
                     raise exception.UnprocessableEntity(message=message)
 
                 try:
-                    max_value = int(rule.get('max'))
+                    max_value = int(rule.max_size)
                 except ValueError:
                     raise exception.TroveError(_(
                         "Invalid or unsupported max value defined in the "
@@ -228,13 +243,13 @@ class ConfigurationsController(wsgi.Controller):
                     raise exception.UnprocessableEntity(message=message)
 
     @staticmethod
-    def _find_type(valueType):
-        if valueType == "boolean":
+    def _find_type(value_type):
+        if value_type == "boolean":
             return bool
-        elif valueType == "string":
+        elif value_type == "string":
             return basestring
-        elif valueType == "integer":
-            return int
+        elif value_type == "integer":
+            return (int, long)
         else:
             raise exception.TroveError(_(
                 "Invalid or unsupported type defined in the "
@@ -253,35 +268,27 @@ class ParametersController(wsgi.Controller):
     def index(self, req, tenant_id, datastore, id):
         ds, ds_version = ds_models.get_datastore_version(
             type=datastore, version=id)
-        rules = configurations.get_validation_rules(
-            datastore_manager=ds_version.manager)
+        rules = models.DatastoreConfigurationParameters.load_parameters(
+            ds_version.id)
         return wsgi.Result(views.ConfigurationParametersView(rules).data(),
                            200)
 
     def show(self, req, tenant_id, datastore, id, name):
         ds, ds_version = ds_models.get_datastore_version(
             type=datastore, version=id)
-        rules = configurations.get_validation_rules(
-            datastore_manager=ds_version.manager)
-        for rule in rules['configuration-parameters']:
-            if rule['name'] == name:
-                return wsgi.Result(
-                    views.ConfigurationParametersView(rule).data(), 200)
-        raise exception.ConfigKeyNotFound(key=name)
+        rule = models.DatastoreConfigurationParameters.load_parameter_by_name(
+            ds_version.id, name)
+        return wsgi.Result(views.ConfigurationParameterView(rule).data(), 200)
 
     def index_by_version(self, req, tenant_id, version):
         ds_version = ds_models.DatastoreVersion.load_by_uuid(version)
-        rules = configurations.get_validation_rules(
-            datastore_manager=ds_version.manager)
+        rules = models.DatastoreConfigurationParameters.load_parameters(
+            ds_version.id)
         return wsgi.Result(views.ConfigurationParametersView(rules).data(),
                            200)
 
     def show_by_version(self, req, tenant_id, version, name):
-        ds_version = ds_models.DatastoreVersion.load_by_uuid(version)
-        rules = configurations.get_validation_rules(
-            datastore_manager=ds_version.manager)
-        for rule in rules['configuration-parameters']:
-            if rule['name'] == name:
-                return wsgi.Result(
-                    views.ConfigurationParametersView(rule).data(), 200)
-        raise exception.ConfigKeyNotFound(key=name)
+        ds_models.DatastoreVersion.load_by_uuid(version)
+        rule = models.DatastoreConfigurationParameters.load_parameter_by_name(
+            version, name)
+        return wsgi.Result(views.ConfigurationParameterView(rule).data(), 200)
