@@ -14,34 +14,33 @@
 #    under the License.
 
 
-from oslo_log import log as logging
-
 from trove.cluster.service import ClusterController
-import trove.common.apischema as apischema
-from trove.common.auth import admin_context
 from trove.common import exception
-from trove.common.i18n import _
 from trove.common import wsgi
+from trove.common.auth import admin_context
 from trove.extensions.mgmt.clusters import models
 from trove.extensions.mgmt.clusters import views
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
+import trove.common.apischema as apischema
 
 LOG = logging.getLogger(__name__)
 
 
-class MgmtClusterController(ClusterController):
+class ClusterController(ClusterController):
     """Controller for cluster functionality."""
     schemas = apischema.mgmt_cluster
 
     @classmethod
     def get_action_schema(cls, body, action_schema):
-        action_type = list(body.keys())[0]
+        action_type = body.keys()[0]
         return action_schema.get(action_type, {})
 
     @admin_context
     def index(self, req, tenant_id):
         """Return a list of clusters."""
-        LOG.debug("Showing a list of clusters for tenant '%s'.", tenant_id)
-        LOG.info("req : '%s'\n\n", req)
+        LOG.debug("Showing a list of clusters for tenant '%s'." % tenant_id)
+        LOG.info(_("req : '%s'\n\n") % req)
         context = req.environ[wsgi.CONTEXT_KEY]
         deleted = None
         deleted_q = req.GET.get('deleted', '').lower()
@@ -56,11 +55,9 @@ class MgmtClusterController(ClusterController):
     @admin_context
     def show(self, req, tenant_id, id):
         """Return a single cluster."""
-        LOG.info("Showing cluster for tenant '%(tenant_id)s'.\n"
-                 "req : '%(req)s'\n"
-                 "id : '%(id)s'", {
-                     "tenant_id": tenant_id, "req": req, "id": id})
-
+        LOG.debug("Showing cluster for tenant '%s'." % tenant_id)
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("id : '%s'\n\n") % id)
         context = req.environ[wsgi.CONTEXT_KEY]
         cluster = models.MgmtCluster.load(context, id)
         return wsgi.Result(
@@ -70,19 +67,31 @@ class MgmtClusterController(ClusterController):
     @admin_context
     def action(self, req, body, tenant_id, id):
         LOG.debug("Committing an action against cluster %(cluster)s for "
-                  "tenant '%(tenant)s'.", {'cluster': id,
-                                           'tenant': tenant_id})
-        LOG.info("req : '%s'\n\n", req)
+                  "tenant '%(tenant)s'." % {'cluster': id,
+                                            'tenant': tenant_id})
+        LOG.info(_("req : '%s'\n\n") % req)
         if not body:
             raise exception.BadRequest(_("Invalid request body."))
         context = req.environ[wsgi.CONTEXT_KEY]
         cluster = models.MgmtCluster.load(context=context, id=id)
+        _actions = {
+            'reset-task': self._action_reset_task
+        }
+        selected_action = None
+        for key in body:
+            if key in _actions:
+                if selected_action is not None:
+                    msg = _("Only one action can be specified per request.")
+                    raise exception.BadRequest(msg)
+                selected_action = _actions[key]
+            else:
+                msg = _("Invalid cluster action: %s.") % key
+                raise exception.BadRequest(msg)
 
-        if 'reset-task' in body:
-            return self._action_reset_task(context, cluster, body)
+        if selected_action:
+            return selected_action(context, cluster, body)
         else:
-            msg = _("Invalid cluster action requested.")
-            raise exception.BadRequest(msg)
+            raise exception.BadRequest(_("Invalid request body."))
 
     def _action_reset_task(self, context, cluster, body):
         cluster.reset_task()
