@@ -14,16 +14,15 @@
 #    under the License.
 
 
-from oslo_log import log as logging
-
-import trove.common.apischema as apischema
-from trove.common.auth import admin_context
 from trove.common import exception
-from trove.common.i18n import _
 from trove.common import wsgi
+from trove.common.auth import admin_context
 from trove.configuration import models as config_models
 from trove.datastore import models as ds_models
 from trove.extensions.mgmt.configuration import views
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
+import trove.common.apischema as apischema
 
 
 LOG = logging.getLogger(__name__)
@@ -75,8 +74,8 @@ class ConfigurationsParameterController(wsgi.Controller):
     def create(self, req, body, tenant_id, version_id):
         """Create configuration parameter for datastore version."""
         LOG.info(_("Creating configuration parameter for datastore"))
-        LOG.debug("req : '%s'\n\n", req)
-        LOG.debug("body : '%s'\n\n", body)
+        LOG.debug("req : '%s'\n\n" % req)
+        LOG.debug("body : '%s'\n\n" % body)
         if not body:
             raise exception.BadRequest(_("Invalid request body."))
 
@@ -102,8 +101,8 @@ class ConfigurationsParameterController(wsgi.Controller):
     def update(self, req, body, tenant_id, version_id, id):
         """Updating configuration parameter for datastore version."""
         LOG.info(_("Updating configuration parameter for datastore"))
-        LOG.debug("req : '%s'\n\n", req)
-        LOG.debug("body : '%s'\n\n", body)
+        LOG.debug("req : '%s'\n\n" % req)
+        LOG.debug("body : '%s'\n\n" % body)
         if not body:
             raise exception.BadRequest(_("Invalid request body."))
 
@@ -127,7 +126,7 @@ class ConfigurationsParameterController(wsgi.Controller):
     def delete(self, req, tenant_id, version_id, id):
         """Delete configuration parameter for datastore version."""
         LOG.info(_("Deleting configuration parameter for datastore"))
-        LOG.debug("req : '%s'\n\n", req)
+        LOG.debug("req : '%s'\n\n" % req)
         ds_config_params = config_models.DatastoreConfigurationParameters
         try:
             ds_config_params.delete(version_id, id)
