@@ -14,15 +14,13 @@
 #    under the License.
 
 
-from oslo_log import log as logging
-
-from trove.common.auth import admin_context
-from trove.common import cfg
 from trove.common import wsgi
+from trove.common.auth import admin_context
 from trove.extensions.mgmt.volume import models
 from trove.extensions.mgmt.volume import views
+from trove.openstack.common import log as logging
+from trove.openstack.common.gettextutils import _
 
-CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
@@ -32,8 +30,8 @@ class StorageController(wsgi.Controller):
     @admin_context
     def index(self, req, tenant_id):
         """Return all storage devices."""
-        LOG.info("req : '%s'\n\n", req)
-        LOG.info("Indexing storage info for tenant '%s'", tenant_id)
+        LOG.info(_("req : '%s'\n\n") % req)
+        LOG.info(_("Indexing storage info for tenant '%s'") % tenant_id)
         context = req.environ[wsgi.CONTEXT_KEY]
-        storages = models.StorageDevices.load(context, CONF.os_region_name)
+        storages = models.StorageDevices.load(context)
         return wsgi.Result(views.StoragesView(storages).data(), 200)
