@@ -16,17 +16,19 @@
 from trove.openstack.common import log as logging
 
 from trove.common import extensions
+from trove.extensions.mgmt.clusters.service import ClusterController
+from trove.extensions.mgmt.configuration import service as conf_service
 from trove.extensions.mgmt.instances.service import MgmtInstanceController
 from trove.extensions.mgmt.host.service import HostController
 from trove.extensions.mgmt.quota.service import QuotaController
 from trove.extensions.mgmt.host.instance import service as hostservice
 from trove.extensions.mgmt.volume.service import StorageController
-
+from trove.extensions.mgmt.upgrade.service import UpgradeController
 
 LOG = logging.getLogger(__name__)
 
 
-class Mgmt(extensions.ExtensionsDescriptor):
+class Mgmt(extensions.ExtensionDescriptor):
 
     def get_name(self):
         return "Mgmt"
@@ -45,6 +47,7 @@ class Mgmt(extensions.ExtensionsDescriptor):
 
     def get_resources(self):
         resources = []
+
         instances = extensions.ResourceExtension(
             '{tenant_id}/mgmt/instances',
             MgmtInstanceController(),
@@ -54,6 +57,12 @@ class Mgmt(extensions.ExtensionsDescriptor):
                             'action': 'POST'})
         resources.append(instances)
 
+        clusters = extensions.ResourceExtension(
+            '{tenant_id}/mgmt/clusters',
+            ClusterController(),
+            member_actions={'action': 'POST'})
+        resources.append(clusters)
+
         hosts = extensions.ResourceExtension(
             '{tenant_id}/mgmt/hosts',
             HostController(),
@@ -80,4 +89,16 @@ class Mgmt(extensions.ExtensionsDescriptor):
             collection_actions={'action': 'POST'})
         resources.append(host_instances)
 
+        upgrade = extensions.ResourceExtension(
+            '{tenant_id}/mgmt/instances/{instance_id}/upgrade',
+            UpgradeController(),
+            member_actions={})
+        resources.append(upgrade)
+
+        datastore_configuration_parameters = extensions.ResourceExtension(
+            '{tenant_id}/mgmt/datastores/versions/{version_id}/parameters',
+            conf_service.ConfigurationsParameterController(),
+            member_actions={})
+        resources.append(datastore_configuration_parameters)
+
         return resources
