@@ -14,11 +14,14 @@
 #    under the License.
 #
 
-from trove.common import cfg
+from trove.openstack.common import log as logging
+
 from trove.common import extensions
+from trove.common import cfg
 from trove.extensions.security_group import service
 
 
+LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
