@@ -14,9 +14,9 @@
 #    under the License.
 
 import os
-import fcntl
-import struct
-import socket
+
+import netifaces
+from trove.common import utils
 
 REDHAT = 'redhat'
 DEBIAN = 'debian'
@@ -29,6 +29,12 @@ def get_os():
         return DEBIAN
 
 
+def file_discovery(file_candidates):
+    for file in file_candidates:
+        if os.path.isfile(file):
+            return file
+
+
 def service_discovery(service_candidates):
     """
     This function discovering how to start, stop, enable, disable service
@@ -63,27 +69,44 @@ def service_discovery(service_candidates):
                 result['cmd_disable'] = "sudo chkconfig %s off" % service
             break
         # check systemd
-        if os.path.isfile("/lib/systemd/system/%s.service" % service):
+        service_path = "/lib/systemd/system/%s.service" % service
+        if os.path.isfile(service_path):
             result['cmd_start'] = "sudo systemctl start %s" % service
             result['cmd_stop'] = "sudo systemctl stop %s" % service
-            result['cmd_enable'] = "sudo systemctl enable %s" % service
-            result['cmd_disable'] = "sudo systemctl disable %s" % service
+
+            # currently "systemctl enable" doesn't work for symlinked units
+            # as described in https://bugzilla.redhat.com/1014311, therefore
+            # replacing a symlink with its real path
+            if os.path.islink(service_path):
+                real_path = os.path.realpath(service_path)
+                result['cmd_enable'] = "sudo systemctl enable %s" % real_path
+                result['cmd_disable'] = ("sudo systemctl disable %s" %
+                                         real_path)
+            else:
+                result['cmd_enable'] = "sudo systemctl enable %s" % service
+                result['cmd_disable'] = "sudo systemctl disable %s" % service
             break
     return result
 
 
-#Uses the Linux SIOCGIFADDR ioctl to find the IP address associated
-# with a network interface, given the name of that interface,
-# e.g. "eth0". The address is returned as a string containing a dotted quad.
-def get_ip_address(ifname='eth0'):
+def get_ip_address(ifname='eth0', address_family=netifaces.AF_INET):
     """
-    Retrieves IP address which assigned to given network interface
+
+    Retrieves IP address which assigned to given network interface. As
+    an interface can have multiple addresses associated with it, the
+    address_family identifies which address is sought. By default
+    this routine returns the AF_INET address.
 
     @parameter ifname network interface (ethX, wlanX, etc.)
+    @parameter address_family the address family being sought
     """
-    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    return socket.inet_ntoa(fcntl.ioctl(
-        s.fileno(),
-        0x8915,  # SIOCGIFADDR
-        struct.pack('256s', ifname[:15])
-    )[20:24])
+    addresses_by_family = netifaces.ifaddresses(ifname)[address_family]
+    return addresses_by_family.pop()['addr']
+
+
+def update_owner(user, group, path):
+    """
+       Changes the owner and group for the path (recursively)
+    """
+    utils.execute_with_timeout("chown", "-R", "%s:%s" % (user, group), path,
+                               run_as_root=True, root_helper="sudo")
