@@ -18,6 +18,7 @@
 
 import os
 from trove.common import cfg
+from trove.common import exception
 from trove.common import instance as rd_instance
 from trove.guestagent import dbaas
 from trove.guestagent import backup
@@ -25,6 +26,7 @@ from trove.guestagent import volume
 from trove.guestagent.datastore.mysql.service import MySqlAppStatus
 from trove.guestagent.datastore.mysql.service import MySqlAdmin
 from trove.guestagent.datastore.mysql.service import MySqlApp
+from trove.guestagent.strategies.replication import get_replication_strategy
 from trove.openstack.common import log as logging
 from trove.openstack.common.gettextutils import _
 from trove.openstack.common import periodic_task
@@ -32,14 +34,18 @@ from trove.openstack.common import periodic_task
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
-MANAGER = CONF.datastore_manager
+MANAGER = CONF.datastore_manager if CONF.datastore_manager else 'mysql'
+REPLICATION_STRATEGY = CONF.get(MANAGER).replication_strategy
+REPLICATION_NAMESPACE = CONF.get(MANAGER).replication_namespace
+REPLICATION_STRATEGY_CLASS = get_replication_strategy(REPLICATION_STRATEGY,
+                                                      REPLICATION_NAMESPACE)
 
 
 class Manager(periodic_task.PeriodicTasks):
 
     @periodic_task.periodic_task(ticks_between_runs=3)
     def update_status(self, context):
-        """Update the status of the MySQL service"""
+        """Update the status of the MySQL service."""
         MySqlAppStatus.get().update()
 
     def change_passwords(self, context, users):
@@ -93,20 +99,20 @@ class Manager(periodic_task.PeriodicTasks):
         return MySqlAdmin().is_root_enabled()
 
     def _perform_restore(self, backup_info, context, restore_location, app):
-        LOG.info(_("Restoring database from backup %s") % backup_info['id'])
+        LOG.info(_("Restoring database from backup %s.") % backup_info['id'])
         try:
             backup.restore(context, backup_info, restore_location)
-        except Exception as e:
-            LOG.error(e)
-            LOG.error("Error performing restore from backup %s",
-                      backup_info['id'])
+        except Exception:
+            LOG.exception(_("Error performing restore from backup %s.") %
+                          backup_info['id'])
             app.status.set_status(rd_instance.ServiceStatuses.FAILED)
             raise
-        LOG.info(_("Restored database successfully"))
+        LOG.info(_("Restored database successfully."))
 
     def prepare(self, context, packages, databases, memory_mb, users,
                 device_path=None, mount_point=None, backup_info=None,
-                config_contents=None, root_password=None, overrides=None):
+                config_contents=None, root_password=None, overrides=None,
+                cluster_config=None):
         """Makes ready DBAAS on a Guest container."""
         MySqlAppStatus.get().begin_install()
         # status end_mysql_install set with secure()
@@ -116,18 +122,20 @@ class Manager(periodic_task.PeriodicTasks):
             #stop and do not update database
             app.stop_db()
             device = volume.VolumeDevice(device_path)
+            # unmount if device is already mounted
+            device.unmount_device(device_path)
             device.format()
             if os.path.exists(mount_point):
                 #rsync exiting data
                 device.migrate_data(mount_point)
             #mount the volume
             device.mount(mount_point)
-            LOG.debug(_("Mounted the volume."))
+            LOG.debug("Mounted the volume.")
             app.start_mysql()
         if backup_info:
             self._perform_restore(backup_info, context,
                                   mount_point, app)
-        LOG.info(_("Securing mysql now."))
+        LOG.debug("Securing MySQL now.")
         app.secure(config_contents, overrides)
         enable_root_on_restore = (backup_info and
                                   MySqlAdmin().is_root_enabled())
@@ -136,6 +144,7 @@ class Manager(periodic_task.PeriodicTasks):
             MySqlAdmin().enable_root(root_password)
         elif enable_root_on_restore:
             app.secure_root(secure_remote_root=False)
+            MySqlAppStatus.get().report_root('root')
         else:
             app.secure_root(secure_remote_root=True)
 
@@ -147,7 +156,7 @@ class Manager(periodic_task.PeriodicTasks):
         if users:
             self.create_user(context, users)
 
-        LOG.info('"prepare" call has finished.')
+        LOG.info(_('Completed setup of MySQL database instance.'))
 
     def restart(self, context):
         app = MySqlApp(MySqlAppStatus.get())
@@ -162,9 +171,8 @@ class Manager(periodic_task.PeriodicTasks):
         app.stop_db(do_not_start_on_reboot=do_not_start_on_reboot)
 
     def get_filesystem_stats(self, context, fs_path):
-        """Gets the filesystem stats for the path given. """
-        mount_point = CONF.get(
-            'mysql' if not MANAGER else MANAGER).mount_point
+        """Gets the filesystem stats for the path given."""
+        mount_point = CONF.get(MANAGER).mount_point
         return dbaas.get_filesystem_volume_stats(mount_point)
 
     def create_backup(self, context, backup_info):
@@ -182,22 +190,103 @@ class Manager(periodic_task.PeriodicTasks):
     def mount_volume(self, context, device_path=None, mount_point=None):
         device = volume.VolumeDevice(device_path)
         device.mount(mount_point, write_to_fstab=False)
-        LOG.debug(_("Mounted the volume."))
+        LOG.debug("Mounted the device %s at the mount point %s." %
+                  (device_path, mount_point))
 
     def unmount_volume(self, context, device_path=None, mount_point=None):
         device = volume.VolumeDevice(device_path)
         device.unmount(mount_point)
-        LOG.debug(_("Unmounted the volume."))
+        LOG.debug("Unmounted the device %s from the mount point %s." %
+                  (device_path, mount_point))
 
     def resize_fs(self, context, device_path=None, mount_point=None):
         device = volume.VolumeDevice(device_path)
         device.resize_fs(mount_point)
-        LOG.debug(_("Resized the filesystem"))
+        LOG.debug("Resized the filesystem %s." % mount_point)
 
     def update_overrides(self, context, overrides, remove=False):
+        LOG.debug("Updating overrides (%s)." % overrides)
         app = MySqlApp(MySqlAppStatus.get())
         app.update_overrides(overrides, remove=remove)
 
     def apply_overrides(self, context, overrides):
+        LOG.debug("Applying overrides (%s)." % overrides)
         app = MySqlApp(MySqlAppStatus.get())
         app.apply_overrides(overrides)
+
+    def get_replication_snapshot(self, context, snapshot_info,
+                                 replica_source_config=None):
+        LOG.debug("Getting replication snapshot.")
+        app = MySqlApp(MySqlAppStatus.get())
+
+        replication = REPLICATION_STRATEGY_CLASS(context)
+        replication.enable_as_master(app, snapshot_info,
+                                     replica_source_config)
+
+        snapshot_id, log_position = (
+            replication.snapshot_for_replication(context, app, None,
+                                                 snapshot_info))
+
+        mount_point = CONF.get(MANAGER).mount_point
+        volume_stats = dbaas.get_filesystem_volume_stats(mount_point)
+
+        replication_snapshot = {
+            'dataset': {
+                'datastore_manager': MANAGER,
+                'dataset_size': volume_stats.get('used', 0.0),
+                'volume_size': volume_stats.get('total', 0.0),
+                'snapshot_id': snapshot_id
+            },
+            'replication_strategy': REPLICATION_STRATEGY,
+            'master': replication.get_master_ref(app, snapshot_info),
+            'log_position': log_position
+        }
+
+        return replication_snapshot
+
+    def _validate_slave_for_replication(self, context, snapshot):
+        if (snapshot['replication_strategy'] != REPLICATION_STRATEGY):
+            raise exception.IncompatibleReplicationStrategy(
+                snapshot.update({
+                    'guest_strategy': REPLICATION_STRATEGY
+                }))
+
+        mount_point = CONF.get(MANAGER).mount_point
+        volume_stats = dbaas.get_filesystem_volume_stats(mount_point)
+        if (volume_stats.get('total', 0.0) <
+                snapshot['dataset']['dataset_size']):
+            raise exception.InsufficientSpaceForReplica(
+                snapshot.update({
+                    'slave_volume_size': volume_stats.get('total', 0.0)
+                }))
+
+    def attach_replication_slave(self, context, snapshot, slave_config):
+        LOG.debug("Attaching replication snapshot.")
+        app = MySqlApp(MySqlAppStatus.get())
+        try:
+            self._validate_slave_for_replication(context, snapshot)
+            replication = REPLICATION_STRATEGY_CLASS(context)
+            replication.enable_as_slave(app, snapshot, slave_config)
+        except Exception:
+            LOG.exception("Error enabling replication.")
+            app.status.set_status(rd_instance.ServiceStatuses.FAILED)
+            raise
+
+    def detach_replica(self, context):
+        LOG.debug("Detaching replica.")
+        app = MySqlApp(MySqlAppStatus.get())
+        replication = REPLICATION_STRATEGY_CLASS(context)
+        replica_info = replication.detach_slave(app)
+        return replica_info
+
+    def cleanup_source_on_replica_detach(self, context, replica_info):
+        LOG.debug("Cleaning up the source on the detach of a replica.")
+        replication = REPLICATION_STRATEGY_CLASS(context)
+        replication.cleanup_source_on_replica_detach(MySqlAdmin(),
+                                                     replica_info)
+
+    def demote_replication_master(self, context):
+        LOG.debug("Demoting replication master.")
+        app = MySqlApp(MySqlAppStatus.get())
+        replication = REPLICATION_STRATEGY_CLASS(context)
+        replication.demote_master(app)
