@@ -19,7 +19,8 @@
 import os
 import re
 import uuid
-from datetime import date
+from collections import defaultdict
+
 import sqlalchemy
 from sqlalchemy import exc
 from sqlalchemy import interfaces
@@ -29,6 +30,7 @@ from trove.common import cfg
 from trove.common import utils as utils
 from trove.common import exception
 from trove.common import instance as rd_instance
+from trove.common.exception import PollTimeOut
 from trove.guestagent.common import operating_system
 from trove.guestagent.common import sql_query
 from trove.guestagent.db import models
@@ -48,6 +50,7 @@ TMP_MYCNF = "/tmp/my.cnf.tmp"
 MYSQL_BASE_DIR = "/var/lib/mysql"
 
 CONF = cfg.CONF
+MANAGER = CONF.datastore_manager if CONF.datastore_manager else 'mysql'
 
 INCLUDE_MARKER_OPERATORS = {
     True: ">=",
@@ -59,6 +62,8 @@ MYSQL_SERVICE_CANDIDATES = ["mysql", "mysqld", "mysql-server"]
 MYSQL_BIN_CANDIDATES = ["/usr/sbin/mysqld", "/usr/libexec/mysqld"]
 MYCNF_OVERRIDES = "/etc/mysql/conf.d/overrides.cnf"
 MYCNF_OVERRIDES_TMP = "/tmp/overrides.cnf.tmp"
+MYCNF_REPLMASTER = "/etc/mysql/conf.d/0replication.cnf"
+MYCNF_REPLMASTER_TMP = "/tmp/replication.cnf.tmp"
 
 
 # Create a package impl
@@ -77,7 +82,7 @@ def clear_expired_password():
         out, err = utils.execute("cat", secret_file,
                                  run_as_root=True, root_helper="sudo")
     except exception.ProcessExecutionError:
-        LOG.debug("/root/.mysql_secret is not exists.")
+        LOG.exception(_("/root/.mysql_secret does not exist."))
         return
     m = re.match('# The random password set for the root user at .*: (.*)',
                  out)
@@ -87,7 +92,7 @@ def clear_expired_password():
                                      "password", "", run_as_root=True,
                                      root_helper="sudo")
         except exception.ProcessExecutionError:
-            LOG.error("Cannot change mysql password.")
+            LOG.exception(_("Cannot change mysql password."))
             return
         utils.execute("rm", "-f", secret_file, run_as_root=True,
                       root_helper="sudo")
@@ -135,13 +140,13 @@ def load_mysqld_options():
         out, err = utils.execute(mysqld_bin, "--print-defaults",
                                  run_as_root=True, root_helper="sudo")
         arglist = re.split("\n", out)[1].split()
-        args = {}
+        args = defaultdict(list)
         for item in arglist:
             if "=" in item:
-                key, value = item.split("=")
-                args[key.lstrip("--")] = value
+                key, value = item.split("=", 1)
+                args[key.lstrip("--")].append(value)
             else:
-                args[item.lstrip("--")] = None
+                args[item.lstrip("--")].append(None)
         return args
     except exception.ProcessExecutionError:
         return {}
@@ -158,29 +163,31 @@ class MySqlAppStatus(service.BaseDbStatus):
         try:
             out, err = utils.execute_with_timeout(
                 "/usr/bin/mysqladmin",
-                "ping", run_as_root=True, root_helper="sudo")
-            LOG.info("Service Status is RUNNING.")
+                "ping", run_as_root=True, root_helper="sudo",
+                log_output_on_error=True)
+            LOG.info(_("MySQL Service Status is RUNNING."))
             return rd_instance.ServiceStatuses.RUNNING
         except exception.ProcessExecutionError:
-            LOG.error("Process execution ")
+            LOG.exception(_("Failed to get database status."))
             try:
                 out, err = utils.execute_with_timeout("/bin/ps", "-C",
                                                       "mysqld", "h")
                 pid = out.split()[0]
                 # TODO(rnirmal): Need to create new statuses for instances
                 # where the mysql service is up, but unresponsive
-                LOG.info('MySQL pid: %(pid)s' % {'pid': pid})
-                LOG.info("Service Status is BLOCKED.")
+                LOG.info(_('MySQL Service Status %(pid)s is BLOCKED.') %
+                         {'pid': pid})
                 return rd_instance.ServiceStatuses.BLOCKED
             except exception.ProcessExecutionError:
+                LOG.exception(_("Process execution failed."))
                 mysql_args = load_mysqld_options()
                 pid_file = mysql_args.get('pid_file',
-                                          '/var/run/mysqld/mysqld.pid')
+                                          ['/var/run/mysqld/mysqld.pid'])[0]
                 if os.path.exists(pid_file):
-                    LOG.info("Service Status is CRASHED.")
+                    LOG.info(_("MySQL Service Status is CRASHED."))
                     return rd_instance.ServiceStatuses.CRASHED
                 else:
-                    LOG.info("Service Status is SHUTDOWN.")
+                    LOG.info(_("MySQL Service Status is SHUTDOWN."))
                     return rd_instance.ServiceStatuses.SHUTDOWN
 
 
@@ -220,7 +227,8 @@ class MySqlAdmin(object):
 
     def _associate_dbs(self, user):
         """Internal. Given a MySQLUser, populate its databases attribute."""
-        LOG.debug("Associating dbs to user %s at %s" % (user.name, user.host))
+        LOG.debug("Associating dbs to user %s at %s." %
+                  (user.name, user.host))
         with LocalSqlClient(get_engine()) as client:
             q = sql_query.Query()
             q.columns = ["grantee", "table_schema"]
@@ -230,7 +238,7 @@ class MySqlAdmin(object):
             t = text(str(q))
             db_result = client.execute(t)
             for db in db_result:
-                LOG.debug("\t db: %s" % db)
+                LOG.debug("\t db: %s." % db)
                 if db['grantee'] == "'%s'@'%s'" % (user.name, user.host):
                     mysql_db = models.MySQLDatabase()
                     mysql_db.name = db['table_schema']
@@ -239,16 +247,15 @@ class MySqlAdmin(object):
     def change_passwords(self, users):
         """Change the passwords of one or more existing users."""
         LOG.debug("Changing the password of some users.")
-        LOG.debug("Users is %s" % users)
         with LocalSqlClient(get_engine()) as client:
             for item in users:
-                LOG.debug("\tUser: %s" % item)
+                LOG.debug("Changing password for user %s." % item)
                 user_dict = {'_name': item['name'],
                              '_host': item['host'],
                              '_password': item['password']}
                 user = models.MySQLUser()
                 user.deserialize(user_dict)
-                LOG.debug("\tDeserialized: %s" % user.__dict__)
+                LOG.debug("\tDeserialized: %s." % user.__dict__)
                 uu = sql_query.UpdateUser(user.name, host=user.host,
                                           clear=user.password)
                 t = text(str(uu))
@@ -256,8 +263,7 @@ class MySqlAdmin(object):
 
     def update_attributes(self, username, hostname, user_attrs):
         """Change the attributes of an existing user."""
-        LOG.debug("Changing the user attributes")
-        LOG.debug("User is %s" % username)
+        LOG.debug("Changing user attributes for user %s." % username)
         user = self._get_user(username, hostname)
         db_access = set()
         grantee = set()
@@ -333,11 +339,15 @@ class MySqlAdmin(object):
 
     def delete_user(self, user):
         """Delete the specified user."""
+        mysql_user = models.MySQLUser()
+        mysql_user.deserialize(user)
+        self.delete_user_by_name(mysql_user.name, mysql_user.host)
+
+    def delete_user_by_name(self, name, host='%'):
         with LocalSqlClient(get_engine()) as client:
-            mysql_user = models.MySQLUser()
-            mysql_user.deserialize(user)
-            du = sql_query.DropUser(mysql_user.name, host=mysql_user.host)
+            du = sql_query.DropUser(name, host=host)
             t = text(str(du))
+            LOG.debug("delete_user_by_name: %s", t)
             client.execute(t)
 
     def get_user(self, username, hostname):
@@ -352,6 +362,7 @@ class MySqlAdmin(object):
         try:
             user.name = username  # Could possibly throw a BadRequest here.
         except exception.ValueError as ve:
+            LOG.exception(_("Error Getting user information"))
             raise exception.BadRequest(_("Username %(user)s is not valid"
                                          ": %(reason)s") %
                                        {'user': username, 'reason': ve.message}
@@ -366,7 +377,7 @@ class MySqlAdmin(object):
             q.order = ['User', 'Host']
             t = text(str(q))
             result = client.execute(t).fetchall()
-            LOG.debug("Result: %s" % result)
+            LOG.debug("Getting user information %s." % result)
             if len(result) != 1:
                 return None
             found_user = result[0]
@@ -384,6 +395,7 @@ class MySqlAdmin(object):
                     try:
                         mydb.name = database
                     except ValueError:
+                        LOG.exception(_("Error granting access"))
                         raise exception.BadRequest(_(
                             "Grant access to %s is not allowed") % database)
 
@@ -405,7 +417,7 @@ class MySqlAdmin(object):
 
     def list_databases(self, limit=None, marker=None, include_marker=False):
         """List databases the user created on this mysql instance."""
-        LOG.debug(_("---Listing Databases---"))
+        LOG.debug("---Listing Databases---")
         databases = []
         with LocalSqlClient(get_engine()) as client:
             # If you have an external volume mounted at /var/lib/mysql
@@ -433,18 +445,18 @@ class MySqlAdmin(object):
             t = text(str(q))
             database_names = client.execute(t)
             next_marker = None
-            LOG.debug(_("database_names = %r") % database_names)
+            LOG.debug("database_names = %r." % database_names)
             for count, database in enumerate(database_names):
                 if count >= limit:
                     break
-                LOG.debug(_("database = %s ") % str(database))
+                LOG.debug("database = %s." % str(database))
                 mysql_db = models.MySQLDatabase()
                 mysql_db.name = database[0]
                 next_marker = mysql_db.name
                 mysql_db.character_set = database[1]
                 mysql_db.collate = database[2]
                 databases.append(mysql_db.serialize())
-        LOG.debug(_("databases = ") + str(databases))
+        LOG.debug("databases = " + str(databases))
         if database_names.rowcount <= limit:
             next_marker = None
         return databases, next_marker
@@ -469,7 +481,7 @@ class MySqlAdmin(object):
             Marker
         LIMIT :limit;
         '''
-        LOG.debug(_("---Listing Users---"))
+        LOG.debug("---Listing Users---")
         users = []
         with LocalSqlClient(get_engine()) as client:
             mysql_user = models.MySQLUser()
@@ -583,24 +595,23 @@ class MySqlApp(object):
         """Prepare the guest machine with a secure
            mysql server installation.
         """
-        LOG.info(_("Preparing Guest as MySQL Server"))
+        LOG.info(_("Preparing Guest as MySQL Server."))
         if not packager.pkg_is_installed(packages):
-            LOG.debug(_("Installing mysql server"))
+            LOG.debug("Installing MySQL server.")
             self._clear_mysql_config()
             # set blank password on pkg configuration stage
             pkg_opts = {'root_password': '',
                         'root_password_again': ''}
             packager.pkg_install(packages, pkg_opts, self.TIME_OUT)
             self._create_mysql_confd_dir()
-            LOG.debug(_("Finished installing mysql server"))
+            LOG.info(_("Finished installing MySQL server."))
         self.start_mysql()
-        LOG.info(_("Dbaas install_if_needed complete"))
 
     def complete_install_or_restart(self):
         self.status.end_install_or_restart()
 
     def secure(self, config_contents, overrides):
-        LOG.info(_("Generating admin password..."))
+        LOG.info(_("Generating admin password."))
         admin_password = utils.generate_random_password()
         clear_expired_password()
         engine = sqlalchemy.create_engine("mysql://root:@localhost:3306",
@@ -613,18 +624,18 @@ class MySqlApp(object):
         self._write_mycnf(admin_password, config_contents, overrides)
         self.start_mysql()
 
-        LOG.info(_("Dbaas secure complete."))
+        LOG.debug("MySQL secure complete.")
 
     def secure_root(self, secure_remote_root=True):
         with LocalSqlClient(get_engine()) as client:
-            LOG.info(_("Preserving root access from restore"))
+            LOG.info(_("Preserving root access from restore."))
             self._generate_root_password(client)
             if secure_remote_root:
                 self._remove_remote_root_access(client)
 
     def _clear_mysql_config(self):
         """Clear old configs, which can be incompatible with new version."""
-        LOG.debug("Clearing old mysql config")
+        LOG.debug("Clearing old MySQL config.")
         random_uuid = str(uuid.uuid4())
         configs = ["/etc/my.cnf", "/etc/mysql/conf.d", "/etc/mysql/my.cnf"]
         for config in configs:
@@ -632,23 +643,25 @@ class MySqlApp(object):
             try:
                 utils.execute_with_timeout(command, shell=True,
                                            root_helper="sudo")
-                LOG.debug("%s saved to %s_%s" % (config, config, random_uuid))
+                LOG.debug("%s saved to %s_%s." %
+                          (config, config, random_uuid))
             except exception.ProcessExecutionError:
                 pass
 
     def _create_mysql_confd_dir(self):
         conf_dir = "/etc/mysql/conf.d"
-        LOG.debug("Creating %s" % conf_dir)
+        LOG.debug("Creating %s." % conf_dir)
         command = "sudo mkdir -p %s" % conf_dir
         utils.execute_with_timeout(command, shell=True)
 
     def _enable_mysql_on_boot(self):
-        LOG.info("Enabling mysql on boot.")
+        LOG.debug("Enabling MySQL on boot.")
         try:
             mysql_service = operating_system.service_discovery(
                 MYSQL_SERVICE_CANDIDATES)
             utils.execute_with_timeout(mysql_service['cmd_enable'], shell=True)
         except KeyError:
+            LOG.exception(_("Error enabling MySQL start on boot."))
             raise RuntimeError("Service is not discovered.")
 
     def _disable_mysql_on_boot(self):
@@ -658,10 +671,11 @@ class MySqlApp(object):
             utils.execute_with_timeout(mysql_service['cmd_disable'],
                                        shell=True)
         except KeyError:
+            LOG.exception(_("Error disabling MySQL start on boot."))
             raise RuntimeError("Service is not discovered.")
 
     def stop_db(self, update_db=False, do_not_start_on_reboot=False):
-        LOG.info(_("Stopping mysql..."))
+        LOG.info(_("Stopping MySQL."))
         if do_not_start_on_reboot:
             self._disable_mysql_on_boot()
         try:
@@ -669,11 +683,12 @@ class MySqlApp(object):
                 MYSQL_SERVICE_CANDIDATES)
             utils.execute_with_timeout(mysql_service['cmd_stop'], shell=True)
         except KeyError:
+            LOG.exception(_("Error stopping MySQL."))
             raise RuntimeError("Service is not discovered.")
         if not self.status.wait_for_real_status_to_change_to(
                 rd_instance.ServiceStatuses.SHUTDOWN,
                 self.state_change_wait_time, update_db):
-            LOG.error(_("Could not stop MySQL!"))
+            LOG.error(_("Could not stop MySQL."))
             self.status.end_install_or_restart()
             raise RuntimeError("Could not stop MySQL!")
 
@@ -704,16 +719,16 @@ class MySqlApp(object):
         """
 
         if overrides_file:
-            LOG.debug(_("writing new overrides.cnf config file"))
+            LOG.debug("Writing new overrides.cnf config file.")
             self._write_config_overrides(overrides_file)
         if remove:
-            LOG.debug(_("removing overrides.cnf config file"))
+            LOG.debug("Removing overrides.cnf config file.")
             self._remove_overrides()
 
     def apply_overrides(self, overrides):
-        LOG.debug(_("applying overrides to mysql"))
+        LOG.debug("Applying overrides to MySQL.")
         with LocalSqlClient(get_engine()) as client:
-            LOG.debug(_("updating overrides values in running daemon"))
+            LOG.debug("Updating override values in running MySQL.")
             for k, v in overrides.iteritems():
                 q = sql_query.SetServerVariable(key=k, value=v)
                 t = text(str(q))
@@ -722,21 +737,7 @@ class MySqlApp(object):
                 except exc.OperationalError:
                     output = {'key': k, 'value': v}
                     LOG.exception(_("Unable to set %(key)s with value "
-                                    "%(value)s") % output)
-
-    def _replace_mycnf_with_template(self, template_path, original_path):
-        LOG.debug(_("replacing the mycnf with template"))
-        LOG.debug(_("template_path(%(template)s) original_path(%(origin)s)")
-                  % {"template": template_path, "origin": original_path})
-        if os.path.isfile(template_path):
-            if os.path.isfile(original_path):
-                utils.execute_with_timeout(
-                    "sudo", "mv", original_path,
-                    "%(name)s.%(date)s" %
-                    {'name': original_path, 'date':
-                        date.today().isoformat()})
-            utils.execute_with_timeout("sudo", "cp", template_path,
-                                       original_path)
+                                    "%(value)s.") % output)
 
     def _write_temp_mycnf_with_admin_account(self, original_file_path,
                                              temp_file_path, password):
@@ -757,20 +758,19 @@ class MySqlApp(object):
         current size of the files MySQL will fail to start, so we delete the
         files to be safe.
         """
-        LOG.info(_("Wiping ib_logfiles..."))
+        LOG.info(_("Wiping ib_logfiles."))
         for index in range(2):
             try:
-                (utils.
-                 execute_with_timeout("sudo", "rm", "%s/ib_logfile%d"
-                                                    % (MYSQL_BASE_DIR, index)))
-            except exception.ProcessExecutionError as pe:
                 # On restarts, sometimes these are wiped. So it can be a race
                 # to have MySQL start up before it's restarted and these have
-                # to be deleted. That's why its ok if they aren't found.
-                LOG.error("Could not delete logfile!")
-                LOG.error(pe)
-                if "No such file or directory" not in str(pe):
-                    raise
+                # to be deleted. That's why its ok if they aren't found and
+                # that is why we use the "-f" option to "rm".
+                (utils.
+                 execute_with_timeout("sudo", "rm", "-f", "%s/ib_logfile%d"
+                                                    % (MYSQL_BASE_DIR, index)))
+            except exception.ProcessExecutionError:
+                LOG.exception("Could not delete logfile.")
+                raise
 
     def _write_mycnf(self, admin_password, config_contents, overrides=None):
         """
@@ -782,16 +782,22 @@ class MySqlApp(object):
         if admin_password is None:
             admin_password = get_auth_password()
 
-        with open(TMP_MYCNF, 'w') as t:
-            t.write(config_contents)
-        utils.execute_with_timeout("sudo", "mv", TMP_MYCNF,
-                                   MYSQL_CONFIG)
+        try:
+            with open(TMP_MYCNF, 'w') as t:
+                t.write(config_contents)
 
-        self._write_temp_mycnf_with_admin_account(MYSQL_CONFIG,
-                                                  TMP_MYCNF,
-                                                  admin_password)
-        utils.execute_with_timeout("sudo", "mv", TMP_MYCNF,
-                                   MYSQL_CONFIG)
+            utils.execute_with_timeout("sudo", "mv", TMP_MYCNF,
+                                       MYSQL_CONFIG)
+
+            self._write_temp_mycnf_with_admin_account(MYSQL_CONFIG,
+                                                      TMP_MYCNF,
+                                                      admin_password)
+
+            utils.execute_with_timeout("sudo", "mv", TMP_MYCNF,
+                                       MYSQL_CONFIG)
+        except Exception:
+            os.unlink(TMP_MYCNF)
+            raise
 
         self.wipe_ib_logfiles()
 
@@ -808,17 +814,132 @@ class MySqlApp(object):
         utils.execute_with_timeout("sudo", "mv", MYCNF_OVERRIDES_TMP,
                                    MYCNF_OVERRIDES)
 
-        LOG.info(_("Setting permissions on overrides.cnf"))
-        utils.execute_with_timeout("sudo", "chmod", "0711",
+        LOG.info(_("Setting permissions on overrides.cnf."))
+        utils.execute_with_timeout("sudo", "chmod", "0644",
                                    MYCNF_OVERRIDES)
 
     def _remove_overrides(self):
-        LOG.info(_("Removing overrides configuration file"))
+        LOG.info(_("Removing overrides configuration file."))
         if os.path.exists(MYCNF_OVERRIDES):
             utils.execute_with_timeout("sudo", "rm", MYCNF_OVERRIDES)
 
+    def write_replication_overrides(self, overrideValues):
+        LOG.info(_("Writing replication.cnf file."))
+
+        with open(MYCNF_REPLMASTER_TMP, 'w') as overrides:
+            overrides.write(overrideValues)
+        LOG.debug("Moving temp replication.cnf into correct location.")
+        utils.execute_with_timeout("sudo", "mv", MYCNF_REPLMASTER_TMP,
+                                   MYCNF_REPLMASTER)
+
+        LOG.debug("Setting permissions on replication.cnf.")
+        utils.execute_with_timeout("sudo", "chmod", "0644",
+                                   MYCNF_REPLMASTER)
+
+    def remove_replication_overrides(self):
+        LOG.info(_("Removing replication configuration file."))
+        if os.path.exists(MYCNF_REPLMASTER):
+            utils.execute_with_timeout("sudo", "rm", MYCNF_REPLMASTER)
+
+    def grant_replication_privilege(self, replication_user):
+        LOG.info(_("Granting Replication Slave privilege."))
+
+        with LocalSqlClient(get_engine()) as client:
+            g = sql_query.Grant(permissions=['REPLICATION SLAVE'],
+                                user=replication_user['name'],
+                                clear=replication_user['password'])
+
+            t = text(str(g))
+            client.execute(t)
+
+    def revoke_replication_privilege(self):
+        LOG.info(_("Revoking Replication Slave privilege."))
+
+        with LocalSqlClient(get_engine()) as client:
+            results = client.execute('SHOW SLAVE STATUS').fetchall()
+            slave_status_info = results[0]
+
+            r = sql_query.Revoke(permissions=['REPLICATION SLAVE'],
+                                 user=slave_status_info['master_user'])
+
+            t = text(str(r))
+            client.execute(t)
+
+    def get_port(self):
+        with LocalSqlClient(get_engine()) as client:
+            result = client.execute('SELECT @@port').first()
+            return result[0]
+
+    def get_binlog_position(self):
+        with LocalSqlClient(get_engine()) as client:
+            result = client.execute('SHOW MASTER STATUS').first()
+            binlog_position = {
+                'log_file': result['File'],
+                'position': result['Position']
+            }
+            return binlog_position
+
+    def change_master_for_binlog(self, host, port, logging_config):
+        LOG.info(_("Configuring replication from %s.") % host)
+
+        replication_user = logging_config['replication_user']
+        change_master_cmd = ("CHANGE MASTER TO MASTER_HOST='%(host)s', "
+                             "MASTER_PORT=%(port)s, "
+                             "MASTER_USER='%(user)s', "
+                             "MASTER_PASSWORD='%(password)s', "
+                             "MASTER_LOG_FILE='%(log_file)s', "
+                             "MASTER_LOG_POS=%(log_pos)s" %
+                             {
+                                 'host': host,
+                                 'port': port,
+                                 'user': replication_user['name'],
+                                 'password': replication_user['password'],
+                                 'log_file': logging_config['log_file'],
+                                 'log_pos': logging_config['log_position']
+                             })
+
+        with LocalSqlClient(get_engine()) as client:
+            client.execute(change_master_cmd)
+
+    def start_slave(self):
+        LOG.info(_("Starting slave replication."))
+        with LocalSqlClient(get_engine()) as client:
+            client.execute('START SLAVE')
+            self._wait_for_slave_status("ON", client, 60)
+
+    def stop_slave(self):
+        replication_user = None
+        LOG.info(_("Stopping slave replication."))
+        with LocalSqlClient(get_engine()) as client:
+            result = client.execute('SHOW SLAVE STATUS')
+            replication_user = result.first()['Master_User']
+            client.execute('STOP SLAVE')
+            client.execute('RESET SLAVE ALL')
+            self._wait_for_slave_status("OFF", client, 30)
+            client.execute('DROP USER ' + replication_user)
+        return {
+            'replication_user': replication_user
+        }
+
+    def _wait_for_slave_status(self, status, client, max_time):
+
+        def verify_slave_status():
+            actual_status = client.execute(
+                "SHOW GLOBAL STATUS like 'slave_running'").first()[1]
+            return actual_status.upper() == status.upper()
+
+        LOG.debug("Waiting for SLAVE_RUNNING to change to %s.", status)
+        try:
+            utils.poll_until(verify_slave_status, sleep_time=3,
+                             time_out=max_time)
+            LOG.info(_("Replication is now %s.") % status.lower())
+        except PollTimeOut:
+            raise RuntimeError(
+                _("Replication is not %(status)s after %(max)d seconds.") % {
+                    'status': status.lower(), 'max': max_time})
+
     def start_mysql(self, update_db=False):
-        LOG.info(_("Starting mysql..."))
+        LOG.info(_("Starting MySQL."))
         # This is the site of all the trouble in the restart tests.
         # Essentially what happens is that mysql start fails, but does not
         # die. It is then impossible to kill the original, so
@@ -841,33 +962,32 @@ class MySqlApp(object):
         if not self.status.wait_for_real_status_to_change_to(
                 rd_instance.ServiceStatuses.RUNNING,
                 self.state_change_wait_time, update_db):
-            LOG.error(_("Start up of MySQL failed!"))
+            LOG.error(_("Start up of MySQL failed."))
             # If it won't start, but won't die either, kill it by hand so we
             # don't let a rouge process wander around.
             try:
                 utils.execute_with_timeout("sudo", "pkill", "-9", "mysql")
-            except exception.ProcessExecutionError as p:
-                LOG.error("Error killing stalled mysql start command.")
-                LOG.error(p)
+            except exception.ProcessExecutionError:
+                LOG.exception(_("Error killing stalled MySQL start command."))
                 # There's nothing more we can do...
             self.status.end_install_or_restart()
             raise RuntimeError("Could not start MySQL!")
 
     def start_db_with_conf_changes(self, config_contents):
-        LOG.info(_("Starting mysql with conf changes..."))
-        LOG.info(_("inside the guest - self.status.is_mysql_running(%s)...")
-                 % self.status.is_running)
+        LOG.info(_("Starting MySQL with conf changes."))
+        LOG.debug("Inside the guest - Status is_running = (%s)."
+                  % self.status.is_running)
         if self.status.is_running:
             LOG.error(_("Cannot execute start_db_with_conf_changes because "
-                        "MySQL state == %s!") % self.status)
+                        "MySQL state == %s.") % self.status)
             raise RuntimeError("MySQL not stopped.")
-        LOG.info(_("Initiating config."))
+        LOG.info(_("Resetting configuration."))
         self._write_mycnf(None, config_contents)
         self.start_mysql(True)
 
     def reset_configuration(self, configuration):
         config_contents = configuration['config_contents']
-        LOG.info(_("Resetting configuration"))
+        LOG.info(_("Resetting configuration."))
         self._write_mycnf(None, config_contents)
 
 
@@ -878,7 +998,7 @@ class MySqlRootAccess(object):
         with LocalSqlClient(get_engine()) as client:
             t = text(sql_query.ROOT_ENABLED)
             result = client.execute(t)
-            LOG.debug("Found %s with remote root access" % result.rowcount)
+            LOG.debug("Found %s with remote root access." % result.rowcount)
             return result.rowcount != 0
 
     @classmethod
@@ -907,7 +1027,7 @@ class MySqlRootAccess(object):
             t = text(str(uu))
             client.execute(t)
 
-            LOG.debug("CONF.root_grant: %s CONF.root_grant_option: %s" %
+            LOG.debug("CONF.root_grant: %s CONF.root_grant_option: %s." %
                       (CONF.root_grant, CONF.root_grant_option))
 
             g = sql_query.Grant(permissions=CONF.root_grant,
