@@ -17,7 +17,7 @@
 import abc
 
 import six
-from trove.common.strategies.strategy import Strategy
+from trove.guestagent.strategy import Strategy
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -27,32 +27,29 @@ class Replication(Strategy):
     __strategy_type__ = 'replication'
     __strategy_ns__ = 'trove.guestagent.strategies.replication'
 
-    def __init__(self):
+    def __init__(self, context):
+        self.context = context
         super(Replication, self).__init__()
 
     @abc.abstractmethod
     def get_master_ref(self, service, snapshot_info):
         """Get reference to master site for replication strategy."""
 
-    def backup_required_for_replication(self):
-        """Indicates whether a backup is required for replication."""
-        return True
-
     @abc.abstractmethod
-    def snapshot_for_replication(self, context, service, adm, location,
+    def snapshot_for_replication(self, context, service, location,
                                  snapshot_info):
         """Capture snapshot of master db."""
 
     @abc.abstractmethod
-    def enable_as_master(self, service, master_config):
+    def enable_as_master(self, service, snapshot_info):
         """Configure underlying database to act as master for replication."""
 
     @abc.abstractmethod
-    def enable_as_slave(self, service, master_info, slave_config):
+    def enable_as_slave(self, service, snapshot):
         """Configure underlying database as a slave of the given master."""
 
     @abc.abstractmethod
-    def detach_slave(self, service, for_failover):
+    def detach_slave(self, service):
         """Turn off replication on a slave site."""
 
     @abc.abstractmethod
@@ -62,18 +59,3 @@ class Replication(Strategy):
     @abc.abstractmethod
     def demote_master(self, service):
         """Turn off replication on a master site."""
-
-    @property
-    def repl_backup_runner(self):
-        """Backup runner to be used to snapshot for replication"""
-        return None
-
-    @property
-    def repl_incr_backup_runner(self):
-        """Incremental backup runner to be used to snapshot for replication"""
-        return None
-
-    @property
-    def repl_backup_extra_opts(self):
-        """Extra options to be passed to the backup agent"""
-        return None
