@@ -89,9 +89,12 @@ class InstanceTasks(object):
                                              'guestagent timeout.',
                                              is_error=True)
     BUILDING_ERROR_SEC_GROUP = InstanceTask(0x53, 'BUILDING',
-                                            'Build error: Security group '
+                                            'Build error: Secgroup '
                                             'or rule.',
                                             is_error=True)
+    BUILDING_ERROR_REPLICA = InstanceTask(0x54, 'BUILDING',
+                                          'Build error: Replica.',
+                                          is_error=True)
 
 # Dissuade further additions at run-time.
 InstanceTask.__init__ = None
