@@ -39,9 +39,19 @@ class InstanceView(object):
             "datastore": {"type": self.instance.datastore.name,
                           "version": self.instance.datastore_version.name},
         }
-        if CONF.trove_volume_support:
+        if self.instance.volume_support:
             instance_dict['volume'] = {'size': self.instance.volume_size}
 
+        if self.instance.hostname:
+            instance_dict['hostname'] = self.instance.hostname
+        else:
+            ip = self.instance.get_visible_ip_addresses()
+            if ip:
+                instance_dict['ip'] = ip
+
+        if self.instance.slave_of_id is not None:
+            instance_dict['replica_of'] = self._build_master_info()
+
         LOG.debug(instance_dict)
         return {"instance": instance_dict}
 
@@ -58,6 +68,13 @@ class InstanceView(object):
         return create_links("flavors", self.req,
                             self.instance.flavor_id)
 
+    def _build_master_info(self):
+        return {
+            "id": self.instance.slave_of_id,
+            "links": create_links("instances", self.req,
+                                  self.instance.slave_of_id)
+        }
+
 
 class InstanceDetailView(InstanceView):
     """Works with a full-blown instance."""
@@ -74,20 +91,17 @@ class InstanceDetailView(InstanceView):
         result['instance']['datastore']['version'] = (self.instance.
                                                       datastore_version.name)
 
+        if self.instance.slaves:
+            result['instance']['replicas'] = self._build_slaves_info()
+
         if self.instance.configuration is not None:
             result['instance']['configuration'] = (self.
                                                    _build_configuration_info())
-        if self.instance.hostname:
-            result['instance']['hostname'] = self.instance.hostname
-        else:
-            ip = self.instance.get_visible_ip_addresses()
-            if ip is not None and len(ip) > 0:
-                result['instance']['ip'] = ip
 
         if (isinstance(self.instance, models.DetailInstance) and
                 self.instance.volume_used):
             used = self.instance.volume_used
-            if CONF.trove_volume_support:
+            if self.instance.volume_support:
                 result['instance']['volume']['used'] = used
             else:
                 # either ephemeral or root partition
@@ -96,8 +110,23 @@ class InstanceDetailView(InstanceView):
         if self.instance.root_password:
             result['instance']['password'] = self.instance.root_password
 
+        if self.instance.cluster_id:
+            result['instance']['cluster_id'] = self.instance.cluster_id
+
+        if self.instance.shard_id:
+            result['instance']['shard_id'] = self.instance.shard_id
+
         return result
 
+    def _build_slaves_info(self):
+        data = []
+        for slave in self.instance.slaves:
+            data.append({
+                "id": slave.id,
+                "links": create_links("instances", self.req, slave.id)
+            })
+        return data
+
     def _build_configuration_info(self):
         return {
             "id": self.instance.configuration.id,
