@@ -20,9 +20,11 @@ Routes all the requests to the task manager.
 
 
 from trove.common import cfg
+from trove.common import exception
+from trove.common import strategy
+from trove.guestagent import models as agent_models
 from trove.openstack.common.rpc import proxy
 from trove.openstack.common import log as logging
-from trove.openstack.common.gettextutils import _
 
 
 CONF = cfg.CONF
@@ -52,6 +54,14 @@ class API(proxy.RpcProxy):
         """Create the routing key for the taskmanager"""
         return CONF.taskmanager_queue
 
+    def _delete_heartbeat(self, instance_id):
+        agent_heart_beat = agent_models.AgentHeartBeat()
+        try:
+            heartbeat = agent_heart_beat.find_by_instance_id(instance_id)
+            heartbeat.delete()
+        except exception.ModelNotFoundError as e:
+            LOG.error(e.message)
+
     def resize_volume(self, new_size, instance_id):
         LOG.debug("Making async call to resize volume for instance: %s"
                   % instance_id)
@@ -78,6 +88,11 @@ class API(proxy.RpcProxy):
         self.cast(self.context,
                   self.make_msg("restart", instance_id=instance_id))
 
+    def detach_replica(self, instance_id):
+        LOG.debug("Making async call to detach replica: %s" % instance_id)
+        self.cast(self.context,
+                  self.make_msg("detach_replica", instance_id=instance_id))
+
     def migrate(self, instance_id, host):
         LOG.debug("Making async call to migrate instance: %s" % instance_id)
         self.cast(self.context,
@@ -87,6 +102,7 @@ class API(proxy.RpcProxy):
         LOG.debug("Making async call to delete instance: %s" % instance_id)
         self.cast(self.context,
                   self.make_msg("delete_instance", instance_id=instance_id))
+        self._delete_heartbeat(instance_id)
 
     def create_backup(self, backup_info, instance_id):
         LOG.debug("Making async call to create a backup for instance: %s" %
@@ -104,7 +120,9 @@ class API(proxy.RpcProxy):
                         image_id, databases, users, datastore_manager,
                         packages, volume_size, backup_id=None,
                         availability_zone=None, root_password=None,
-                        nics=None, overrides=None):
+                        nics=None, overrides=None, slave_of_id=None,
+                        cluster_config=None):
+
         LOG.debug("Making async call to create instance %s " % instance_id)
         self.cast(self.context,
                   self.make_msg("create_instance",
@@ -121,11 +139,13 @@ class API(proxy.RpcProxy):
                                 availability_zone=availability_zone,
                                 root_password=root_password,
                                 nics=nics,
-                                overrides=overrides))
+                                overrides=overrides,
+                                slave_of_id=slave_of_id,
+                                cluster_config=cluster_config))
 
     def update_overrides(self, instance_id, overrides=None):
-        LOG.debug(_("Making async call to update configuration overrides for "
-                    "instance %s") % instance_id)
+        LOG.debug("Making async call to update datastore configurations for "
+                  "instance %s" % instance_id)
 
         self.cast(self.context,
                   self.make_msg("update_overrides",
@@ -133,11 +153,32 @@ class API(proxy.RpcProxy):
                                 overrides=overrides))
 
     def unassign_configuration(self, instance_id, flavor, configuration_id):
-        LOG.debug(_("Making async call to unassign configuration for "
-                    "instance %s") % instance_id)
+        LOG.debug("Making async call to remove datastore configurations for "
+                  "instance %s" % instance_id)
 
         self.cast(self.context,
                   self.make_msg("unassign_configuration",
                                 instance_id=instance_id,
                                 flavor=self._transform_obj(flavor),
                                 configuration_id=configuration_id))
+
+    def create_cluster(self, cluster_id):
+        LOG.debug("Making async call to create cluster %s " % cluster_id)
+        self.cast(self.context,
+                  self.make_msg("create_cluster",
+                                cluster_id=cluster_id))
+
+    def delete_cluster(self, cluster_id):
+        LOG.debug("Making async call to delete cluster %s " % cluster_id)
+        self.cast(self.context,
+                  self.make_msg("delete_cluster",
+                                cluster_id=cluster_id))
+
+
+def load(context, manager=None):
+    if manager:
+        task_manager_api_class = (strategy.load_taskmanager_strategy(manager)
+                                  .task_manager_api_class)
+    else:
+        task_manager_api_class = API
+    return task_manager_api_class(context)
