@@ -15,6 +15,7 @@
 
 
 import json
+from time import sleep
 from datetime import datetime
 from proboscis import SkipTest
 from proboscis import test
@@ -32,7 +33,6 @@ from trove.tests.api.instances import TIMEOUT_INSTANCE_DELETE
 from trove.tests.api.instances import WaitForGuestInstallationToFinish
 from trove.tests.config import CONFIG
 from trove.tests.util import create_dbaas_client
-from trove.tests.util import test_config
 from trove.tests.util.check import AttrCheck
 from trove.tests.util.check import CollectionCheck
 from trove.tests.util.check import TypeCheck
@@ -57,6 +57,14 @@ sql_variables = [
 ]
 
 
+def _is_valid_timestamp(time_string):
+    try:
+        datetime.strptime(time_string, "%Y-%m-%dT%H:%M:%S")
+    except ValueError:
+        return False
+    return True
+
+
 # helper methods to validate configuration is applied to instance
 def _execute_query(host, user_name, password, query):
     print(host, user_name, password, query)
@@ -133,12 +141,34 @@ def _test_configuration_is_applied_to_instance(instance, configuration_id):
         assert_true(converted_key_value in testconfig_info.values.items())
 
 
+class ConfigurationsTestBase(object):
+
+    @staticmethod
+    def expected_instance_datastore_configs(instance_id):
+        """Given an instance retrieve the expected test configurations for
+        instance's datastore.
+        """
+        instance = instance_info.dbaas.instances.get(instance_id)
+        datastore_type = instance.datastore['type']
+        datastore_test_configs = CONFIG.get(datastore_type, {})
+        return datastore_test_configs.get("configurations", {})
+
+    @staticmethod
+    def expected_default_datastore_configs():
+        """Returns the expected test configurations for the default datastore
+        defined in the Test Config as dbaas_datastore.
+        """
+        default_datatstore = CONFIG.get('dbaas_datastore', None)
+        datastore_test_configs = CONFIG.get(default_datatstore, {})
+        return datastore_test_configs.get("configurations", {})
+
+
 @test(depends_on_classes=[WaitForGuestInstallationToFinish], groups=[GROUP])
-class CreateConfigurations(object):
+class CreateConfigurations(ConfigurationsTestBase):
 
     @test
     def test_expected_configurations_parameters(self):
-        """test get expected configurations parameters"""
+        """Test get expected configurations parameters."""
         expected_attrs = ["configuration-parameters"]
         instance_info.dbaas.configuration_parameters.parameters(
             instance_info.dbaas_datastore,
@@ -153,7 +183,8 @@ class CreateConfigurations(object):
         config_param_keys = []
         for param in config_params_list:
             config_param_keys.append(param['name'])
-        expected_config_params = ['key_buffer_size', 'connect_timeout']
+        expected_configs = self.expected_default_datastore_configs()
+        expected_config_params = expected_configs.get('parameters_list')
         # check for duplicate configuration parameters
         msg = "check for duplicate configuration parameters"
         assert_equal(len(config_param_keys), len(set(config_param_keys)), msg)
@@ -164,8 +195,10 @@ class CreateConfigurations(object):
     def test_expected_get_configuration_parameter(self):
         # tests get on a single parameter to verify it has expected attributes
         param = 'key_buffer_size'
-        expected_config_params = ['name', 'restart_required', 'max',
-                                  'min', 'type']
+        expected_config_params = ['name', 'restart_required',
+                                  'max_size', 'min_size', 'type',
+                                  'deleted', 'deleted_at',
+                                  'datastore_version_id']
         instance_info.dbaas.configuration_parameters.get_parameter(
             instance_info.dbaas_datastore,
             instance_info.dbaas_datastore_version,
@@ -182,39 +215,56 @@ class CreateConfigurations(object):
 
     @test
     def test_configurations_create_invalid_values(self):
-        """test create configurations with invalid values"""
+        """Test create configurations with invalid values."""
         values = '{"this_is_invalid": 123}'
-        assert_unprocessable(instance_info.dbaas.configurations.create,
-                             CONFIG_NAME, values, CONFIG_DESC)
+        try:
+            instance_info.dbaas.configurations.create(
+                CONFIG_NAME,
+                values,
+                CONFIG_DESC)
+        except exceptions.NotFound:
+            resp, body = instance_info.dbaas.client.last_response
+            assert_equal(resp.status, 404)
 
     @test
     def test_configurations_create_invalid_value_type(self):
-        """test create configuration with invalild value type"""
+        """Test create configuration with invalild value type."""
         values = '{"key_buffer_size": "this is a string not int"}'
         assert_unprocessable(instance_info.dbaas.configurations.create,
                              CONFIG_NAME, values, CONFIG_DESC)
 
     @test
     def test_configurations_create_value_out_of_bounds(self):
-        """test create configuration with value out of bounds"""
-        values = '{"connect_timeout": 1000000}'
+        """Test create configuration with value out of bounds."""
+        expected_configs = self.expected_default_datastore_configs()
+        values = json.dumps(expected_configs.get('out_of_bounds_over'))
         assert_unprocessable(instance_info.dbaas.configurations.create,
                              CONFIG_NAME, values, CONFIG_DESC)
-        values = '{"connect_timeout": -10}'
+        values = json.dumps(expected_configs.get('out_of_bounds_under'))
         assert_unprocessable(instance_info.dbaas.configurations.create,
                              CONFIG_NAME, values, CONFIG_DESC)
 
     @test
     def test_valid_configurations_create(self):
         # create a configuration with valid parameters
-        values = ('{"connect_timeout": 120, "local_infile": true, '
-                  '"collation_server": "latin1_swedish_ci"}')
+        expected_configs = self.expected_default_datastore_configs()
+        values = json.dumps(expected_configs.get('valid_values'))
         expected_values = json.loads(values)
-        result = instance_info.dbaas.configurations.create(CONFIG_NAME,
-                                                           values,
-                                                           CONFIG_DESC)
+        result = instance_info.dbaas.configurations.create(
+            CONFIG_NAME,
+            values,
+            CONFIG_DESC,
+            datastore=instance_info.dbaas_datastore,
+            datastore_version=instance_info.dbaas_datastore_version)
         resp, body = instance_info.dbaas.client.last_response
         assert_equal(resp.status, 200)
+        with TypeCheck('Configuration', result) as configuration:
+            configuration.has_field('name', basestring)
+            configuration.has_field('description', basestring)
+            configuration.has_field('values', dict)
+            configuration.has_field('datastore_name', basestring)
+            configuration.has_field('datastore_version_id', unicode)
+            configuration.has_field('datastore_version_name', basestring)
         global configuration_info
         configuration_info = result
         assert_equal(configuration_info.name, CONFIG_NAME)
@@ -225,7 +275,11 @@ class CreateConfigurations(object):
     def test_appending_to_existing_configuration(self):
         # test being able to update and insert new parameter name and values
         # to an existing configuration
-        values = '{"join_buffer_size": 1048576, "connect_timeout": 60}'
+        expected_configs = self.expected_default_datastore_configs()
+        values = json.dumps(expected_configs.get('appending_values'))
+        # ensure updated timestamp is different than created
+        if not CONFIG.fake_mode:
+            sleep(1)
         instance_info.dbaas.configurations.edit(configuration_info.id,
                                                 values)
         resp, body = instance_info.dbaas.client.last_response
@@ -233,7 +287,7 @@ class CreateConfigurations(object):
 
 
 @test(runs_after=[CreateConfigurations], groups=[GROUP])
-class AfterConfigurationsCreation(object):
+class AfterConfigurationsCreation(ConfigurationsTestBase):
 
     @test
     def test_assign_configuration_to_invalid_instance(self):
@@ -259,7 +313,16 @@ class AfterConfigurationsCreation(object):
         assert_equal(resp.status, 202)
 
     @test(depends_on=[test_assign_configuration_to_valid_instance])
-    @time_out(10)
+    def test_assign_configuration_to_instance_with_config(self):
+        # test assigning a configuration to an instance that
+        # already has an assigned configuration
+        config_id = configuration_info.id
+        assert_raises(exceptions.BadRequest,
+                      instance_info.dbaas.instances.modify, instance_info.id,
+                      configuration=config_id)
+
+    @test(depends_on=[test_assign_configuration_to_valid_instance])
+    @time_out(30)
     def test_get_configuration_details_from_instance_validation(self):
         # validate that the configuraiton was applied correctly to the instance
         inst = instance_info.dbaas.instances.get(instance_info.id)
@@ -282,8 +345,24 @@ class AfterConfigurationsCreation(object):
             check.has_field("name", basestring)
             check.has_field("description", basestring)
             check.has_field("values", dict)
+            check.has_field("created", basestring)
+            check.has_field("updated", basestring)
+            check.has_field("instance_count", int)
 
         print(result.values)
+
+        # check for valid timestamps
+        assert_true(_is_valid_timestamp(result.created))
+        assert_true(_is_valid_timestamp(result.updated))
+
+        # check that created and updated timestamps differ, since
+        # test_appending_to_existing_configuration should have changed the
+        # updated timestamp
+        if not CONFIG.fake_mode:
+            assert_not_equal(result.created, result.updated)
+
+        assert_equal(result.instance_count, 1)
+
         with CollectionCheck("configuration_values", result.values) as check:
             # check each item has the correct type according to the rules
             for (item_key, item_val) in result.values.iteritems():
@@ -320,12 +399,21 @@ class AfterConfigurationsCreation(object):
 
 
 @test(runs_after=[AfterConfigurationsCreation], groups=[GROUP])
-class ListConfigurations(object):
+class ListConfigurations(ConfigurationsTestBase):
 
     @test
     def test_configurations_list(self):
         # test listing configurations show up
         result = instance_info.dbaas.configurations.list()
+        for conf in result:
+            with TypeCheck("Configuration", conf) as check:
+                check.has_field('id', basestring)
+                check.has_field('name', basestring)
+                check.has_field('description', basestring)
+                check.has_field('datastore_version_id', basestring)
+                check.has_field('datastore_version_name', basestring)
+                check.has_field('datastore_name', basestring)
+
         exists = [config for config in result if
                   config.id == configuration_info.id]
         assert_equal(1, len(exists))
@@ -358,8 +446,8 @@ class ListConfigurations(object):
     def test_changing_configuration_with_nondynamic_parameter(self):
         # test that changing a non-dynamic parameter is applied to instance
         # and show that the instance requires a restart
-        values = ('{"join_buffer_size":1048576,'
-                  '"innodb_buffer_pool_size":57671680}')
+        expected_configs = self.expected_default_datastore_configs()
+        values = json.dumps(expected_configs.get('nondynamic_parameter'))
         instance_info.dbaas.configurations.update(configuration_info.id,
                                                   values)
         resp, body = instance_info.dbaas.client.last_response
@@ -405,7 +493,7 @@ class ListConfigurations(object):
         poll_until(result_is_active)
 
     @test(depends_on=[test_restart_service_should_return_active])
-    @time_out(10)
+    @time_out(30)
     def test_get_configuration_details_from_instance_validation(self):
         # validate that the configuraiton was applied correctly to the instance
         inst = instance_info.dbaas.instances.get(instance_info.id)
@@ -414,16 +502,25 @@ class ListConfigurations(object):
         _test_configuration_is_applied_to_instance(instance_info,
                                                    configuration_id)
 
+    @test(depends_on=[test_configurations_list])
+    def test_compare_list_and_details_timestamps(self):
+        # compare config timestamps between list and details calls
+        result = instance_info.dbaas.configurations.list()
+        list_config = [config for config in result if
+                       config.id == configuration_info.id]
+        assert_equal(1, len(list_config))
+        details_config = instance_info.dbaas.configurations.get(
+            configuration_info.id)
+        assert_equal(list_config[0].created, details_config.created)
+        assert_equal(list_config[0].updated, details_config.updated)
+
 
 @test(runs_after=[ListConfigurations], groups=[GROUP])
-class StartInstanceWithConfiguration(object):
+class StartInstanceWithConfiguration(ConfigurationsTestBase):
 
     @test
     def test_start_instance_with_configuration(self):
         # test that a new instance will apply the configuration on create
-        if test_config.auth_strategy == "fake":
-            raise SkipTest("Skipping instance start with configuration "
-                           "test for fake mode.")
         global configuration_instance
         databases = []
         databases.append({"name": "firstdbconfig", "character_set": "latin2",
@@ -453,15 +550,12 @@ class StartInstanceWithConfiguration(object):
 
 
 @test(runs_after=[StartInstanceWithConfiguration], groups=[GROUP])
-class WaitForConfigurationInstanceToFinish(object):
+class WaitForConfigurationInstanceToFinish(ConfigurationsTestBase):
 
     @test
     @time_out(TIMEOUT_INSTANCE_CREATE)
     def test_instance_with_configuration_active(self):
         # wait for the instance to become active
-        if test_config.auth_strategy == "fake":
-            raise SkipTest("Skipping instance start with configuration "
-                           "test for fake mode.")
 
         def result_is_active():
             instance = instance_info.dbaas.instances.get(
@@ -475,7 +569,7 @@ class WaitForConfigurationInstanceToFinish(object):
         poll_until(result_is_active)
 
     @test(depends_on=[test_instance_with_configuration_active])
-    @time_out(10)
+    @time_out(30)
     def test_get_configuration_details_from_instance_validation(self):
         # validate that the configuraiton was applied correctly to the instance
         inst = instance_info.dbaas.instances.get(configuration_instance.id)
@@ -486,7 +580,7 @@ class WaitForConfigurationInstanceToFinish(object):
 
 
 @test(runs_after=[WaitForConfigurationInstanceToFinish], groups=[GROUP])
-class DeleteConfigurations(object):
+class DeleteConfigurations(ConfigurationsTestBase):
 
     @test
     def test_delete_invalid_configuration_not_found(self):
@@ -496,7 +590,25 @@ class DeleteConfigurations(object):
                       instance_info.dbaas.configurations.delete,
                       invalid_configuration_id)
 
-    @test
+    @test(depends_on=[test_delete_invalid_configuration_not_found])
+    def test_delete_configuration_parameter_with_mgmt_api(self):
+        # delete a parameter that is used by a test
+        # connect_timeout
+        ds = instance_info.dbaas_datastore
+        ds_v = instance_info.dbaas_datastore_version
+        version = instance_info.dbaas.datastore_versions.get(
+            ds, ds_v)
+        client = instance_info.dbaas_admin.mgmt_configs
+        config_param_name = sql_variables[1]
+        client.delete(version.id, config_param_name)
+        assert_raises(
+            exceptions.NotFound,
+            instance_info.dbaas.configuration_parameters.get_parameter,
+            ds,
+            ds_v,
+            config_param_name)
+
+    @test(depends_on=[test_delete_configuration_parameter_with_mgmt_api])
     def test_unable_delete_instance_configurations(self):
         # test deleting a configuration that is assigned to
         # an instance is not allowed.
@@ -530,14 +642,25 @@ class DeleteConfigurations(object):
         poll_until(result_has_no_configuration)
         inst_info = configuration_instance
         poll_until(result_has_no_configuration)
+        instance = instance_info.dbaas.instances.get(instance_info.id)
+        assert_equal('RESTART_REQUIRED', instance.status)
 
     @test(depends_on=[test_unassign_configuration_from_instances])
+    def test_assign_in_wrong_state(self):
+        # test assigning a config to an instance in RESTART state
+        assert_raises(exceptions.BadRequest,
+                      instance_info.dbaas.instances.modify,
+                      configuration_instance.id,
+                      configuration=configuration_info.id)
+
+    @test(depends_on=[test_assign_in_wrong_state])
     def test_no_instances_on_configuration(self):
         # test there is no configuration on the instance after unassigning
         result = instance_info.dbaas.configurations.get(configuration_info.id)
         assert_equal(configuration_info.id, result.id)
         assert_equal(configuration_info.name, result.name)
         assert_equal(configuration_info.description, result.description)
+        assert_equal(result.instance_count, 0)
         print(configuration_instance.id)
         print(instance_info.id)
 
