@@ -19,9 +19,12 @@ import hashlib
 import os
 import testtools
 
+from trove.common import utils
 from trove.common.context import TroveContext
 from trove.conductor import api as conductor_api
+from trove.guestagent.common import operating_system
 from trove.guestagent.strategies.backup import mysql_impl
+from trove.guestagent.strategies.backup import couchbase_impl
 from trove.guestagent.strategies.restore.base import RestoreRunner
 from trove.backup.models import BackupState
 from trove.guestagent.backup import backupagent
@@ -61,7 +64,7 @@ class MockCheckProcessBackup(MockBackup):
 
 
 class MockLossyBackup(MockBackup):
-    """Fake Incomplete writes to swift"""
+    """Fake Incomplete writes to swift."""
 
     def read(self, *args):
         results = super(MockLossyBackup, self).read(*args)
@@ -71,7 +74,7 @@ class MockLossyBackup(MockBackup):
 
 
 class MockSwift(object):
-    """Store files in String"""
+    """Store files in String."""
 
     def __init__(self, *args, **kwargs):
         self.store = ''
@@ -162,9 +165,13 @@ class BackupAgentTest(testtools.TestCase):
         mysql_impl.get_auth_password = MagicMock(return_value='123')
         backupagent.get_storage_strategy = MagicMock(return_value=MockSwift)
         os.statvfs = MagicMock(return_value=MockStats)
+        self.orig_utils_execute_with_timeout = utils.execute_with_timeout
+        self.orig_os_get_ip_address = operating_system.get_ip_address
 
     def tearDown(self):
         super(BackupAgentTest, self).tearDown()
+        utils.execute_with_timeout = self.orig_utils_execute_with_timeout
+        operating_system.get_ip_address = self.orig_os_get_ip_address
 
     def test_backup_impl_MySQLDump(self):
         """This test is for
@@ -205,6 +212,18 @@ class BackupAgentTest(testtools.TestCase):
         str_innobackup_manifest = 'innobackupex.xbstream.gz.enc'
         self.assertEqual(inno_backup_ex.manifest, str_innobackup_manifest)
 
+    def test_backup_impl_CbBackup(self):
+        operating_system.get_ip_address = Mock(return_value="1.1.1.1")
+        utils.execute_with_timeout = Mock(return_value=None)
+        cbbackup = couchbase_impl.CbBackup('cbbackup', extra_opts='')
+        self.assertIsNotNone(cbbackup)
+        str_cbbackup_cmd = ("tar cpPf - /tmp/backups | "
+                            "gzip | openssl enc -aes-256-cbc -salt -pass "
+                            "pass:default_aes_cbc_key")
+        self.assertEqual(str_cbbackup_cmd, cbbackup.cmd)
+        self.assertIsNotNone(cbbackup.manifest)
+        self.assertIn('gz.enc', cbbackup.manifest)
+
     def test_backup_base(self):
         """This test is for
            guestagent/strategies/backup/base
@@ -234,6 +253,8 @@ class BackupAgentTest(testtools.TestCase):
                        'location': 'fake-location',
                        'type': 'InnoBackupEx',
                        'checksum': 'fake-checksum',
+                       'datastore': 'mysql',
+                       'datastore_version': '5.5'
                        }
         agent.execute_backup(context=None, backup_info=backup_info,
                              runner=MockBackup)
@@ -267,6 +288,8 @@ class BackupAgentTest(testtools.TestCase):
                        'location': 'fake-location',
                        'type': 'InnoBackupEx',
                        'checksum': 'fake-checksum',
+                       'datastore': 'mysql',
+                       'datastore_version': '5.5'
                        }
 
         self.assertRaises(backupagent.BackupError, agent.execute_backup,
