@@ -17,32 +17,27 @@ import uuid
 
 from mock import Mock
 from mock import patch
+from testtools import TestCase
 from trove.cluster.models import Cluster
 from trove.cluster.models import ClusterTasks
 from trove.cluster.models import DBCluster
 from trove.common import cfg
 from trove.common import exception
 from trove.common import remote
-from trove.common.strategies.cluster.experimental.mongodb import (
-    api as mongodb_api)
-from trove.common import utils
+from trove.common.strategies.mongodb import api as mongodb_api
 from trove.datastore import models as datastore_models
 from trove.instance import models as inst_models
 from trove.instance.models import DBInstance
 from trove.instance.tasks import InstanceTasks
 from trove.quota.quota import QUOTAS
 from trove.taskmanager import api as task_api
-from trove.tests.unittests import trove_testtools
 
 CONF = cfg.CONF
 
 
-class ClusterTest(trove_testtools.TestCase):
+class ClusterTest(TestCase):
     def setUp(self):
         super(ClusterTest, self).setUp()
-        self.get_client_patch = patch.object(task_api.API, 'get_client')
-        self.get_client_mock = self.get_client_patch.start()
-        self.addCleanup(self.get_client_patch.stop)
         self.cluster_id = str(uuid.uuid4())
         self.cluster_name = "Cluster" + self.cluster_id
         self.tenant_id = "23423432"
@@ -53,7 +48,7 @@ class ClusterTest(trove_testtools.TestCase):
                                  tenant_id=self.tenant_id,
                                  datastore_version_id=self.dv_id,
                                  task_id=ClusterTasks.NONE._code)
-        self.context = trove_testtools.TroveTestContext(self)
+        self.context = Mock()
         self.datastore = Mock()
         self.dv = Mock()
         self.dv.manager = "mongodb"
@@ -61,7 +56,6 @@ class ClusterTest(trove_testtools.TestCase):
         self.cluster = mongodb_api.MongoDbCluster(self.context, self.db_info,
                                                   self.datastore,
                                                   self.datastore_version)
-        self.cluster._server_group_loaded = True
         self.instances = [{'volume_size': 1, 'flavor_id': '1234'},
                           {'volume_size': 1, 'flavor_id': '1234'},
                           {'volume_size': 1, 'flavor_id': '1234'}]
@@ -80,11 +74,10 @@ class ClusterTest(trove_testtools.TestCase):
                           self.cluster_name,
                           self.datastore,
                           self.datastore_version,
-                          [],
-                          {}, None, None)
+                          []
+                          )
 
-    @patch.object(remote, 'create_nova_client')
-    def test_create_unequal_flavors(self, mock_client):
+    def test_create_unequal_flavors(self):
         instances = self.instances
         instances[0]['flavor_id'] = '4567'
         self.assertRaises(exception.ClusterFlavorsNotEqual,
@@ -93,8 +86,8 @@ class ClusterTest(trove_testtools.TestCase):
                           self.cluster_name,
                           self.datastore,
                           self.datastore_version,
-                          instances,
-                          {}, None, None)
+                          instances
+                          )
 
     @patch.object(remote, 'create_nova_client')
     def test_create_unequal_volumes(self,
@@ -109,13 +102,13 @@ class ClusterTest(trove_testtools.TestCase):
                           self.cluster_name,
                           self.datastore,
                           self.datastore_version,
-                          instances,
-                          {}, None, None)
+                          instances
+                          )
 
     @patch.object(remote, 'create_nova_client')
     def test_create_storage_not_specified(self,
                                           mock_client):
-        class FakeFlavor(object):
+        class FakeFlavor:
             def __init__(self, flavor_id):
                 self.flavor_id = flavor_id
 
@@ -138,11 +131,10 @@ class ClusterTest(trove_testtools.TestCase):
                           self.cluster_name,
                           self.datastore,
                           self.datastore_version,
-                          instances,
-                          {}, None, None)
+                          instances
+                          )
 
-    @patch('trove.cluster.models.LOG')
-    def test_delete_bad_task_status(self, mock_logging):
+    def test_delete_bad_task_status(self):
         self.cluster.db_info.task_status = ClusterTasks.BUILDING_INITIAL
         self.assertRaises(exception.UnprocessableEntity,
                           self.cluster.delete)
@@ -169,14 +161,12 @@ class ClusterTest(trove_testtools.TestCase):
         self.cluster.delete()
         mock_update_db.assert_called_with(task_status=ClusterTasks.DELETING)
 
-    @patch('trove.common.strategies.cluster.experimental.mongodb.api.LOG')
-    def test_add_shard_bad_task_status(self, mock_logging):
+    def test_add_shard_bad_task_status(self):
         task_status = ClusterTasks.BUILDING_INITIAL
         self.cluster.db_info.task_status = task_status
         self.assertRaises(exception.UnprocessableEntity,
                           self.cluster.add_shard)
 
-    @patch.object(utils, 'generate_uuid', Mock(return_value='new-shard-id'))
     @patch.object(datastore_models.DatastoreVersion, 'load_by_uuid')
     @patch.object(task_api, 'load')
     @patch.object(Cluster, 'update_db')
@@ -213,11 +203,6 @@ class ClusterTest(trove_testtools.TestCase):
         mock_task_api.mongodb_add_shard_cluster.return_value = None
         mock_task_api_load.return_value = mock_task_api
         self.cluster.add_shard()
-        mock_update_db.assert_called_with(
-            task_status=ClusterTasks.ADDING_SHARD)
-        mock_task_api.mongodb_add_shard_cluster.assert_called_with(
-            self.cluster.id, 'new-shard-id', 'rs2')
-
-    @patch('trove.cluster.models.LOG')
-    def test_upgrade_not_implemented(self, mock_logging):
-        self.assertRaises(exception.BadRequest, self.cluster.upgrade, "foo")
+        mock_update_db.assert_called_with(task_status=
+                                          ClusterTasks.ADDING_SHARD)
+        mock_task_api.mongodb_add_shard_cluster.assert_called
