@@ -10,17 +10,14 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
-from mock import patch
+import testtools
 import uuid
-
 from trove.common import exception
 from trove.guestagent.models import AgentHeartBeat
-from trove.tests.unittests import trove_testtools
 from trove.tests.unittests.util import util
 
 
-class AgentHeartBeatTest(trove_testtools.TestCase):
+class AgentHeartBeatTest(testtools.TestCase):
 
     def setUp(self):
         super(AgentHeartBeatTest, self).setUp()
@@ -83,11 +80,11 @@ class AgentHeartBeatTest(trove_testtools.TestCase):
         heartbeat_found = AgentHeartBeat.find_by_instance_id(
             instance_id=instance_id)
         self.assertIsNotNone(heartbeat_found)
-        self.assertEqual(heartbeat.id, heartbeat_found.id)
-        self.assertEqual(heartbeat.instance_id, heartbeat_found.instance_id)
-        self.assertEqual(heartbeat.updated_at, heartbeat_found.updated_at)
-        self.assertEqual(heartbeat.guest_agent_version,
-                         heartbeat_found.guest_agent_version)
+        self.assertEqual(heartbeat_found.id, heartbeat.id)
+        self.assertEqual(heartbeat_found.instance_id, heartbeat.instance_id)
+        self.assertEqual(heartbeat_found.updated_at, heartbeat.updated_at)
+        self.assertEqual(
+            heartbeat_found.guest_agent_version, heartbeat.guest_agent_version)
 
     def test_find_by_instance_id_none(self):
         """
@@ -104,8 +101,7 @@ class AgentHeartBeatTest(trove_testtools.TestCase):
         self.assertIsNone(heartbeat_found)
         self.assertTrue(exception_raised)
 
-    @patch('trove.guestagent.models.LOG')
-    def test_find_by_instance_id_not_found(self, mock_logging):
+    def test_find_by_instance_id_not_found(self):
         """
         Test to retrieve a guest agents when id is not found
         """
@@ -128,7 +124,7 @@ class AgentHeartBeatTest(trove_testtools.TestCase):
         # create some unique records with the same version
         version = str(uuid.uuid4())
 
-        for x in range(5):
+        for x in xrange(5):
             instance_id = str(uuid.uuid4())
             heartbeat = AgentHeartBeat.create(
                 instance_id=instance_id,
@@ -190,11 +186,11 @@ class AgentHeartBeatTest(trove_testtools.TestCase):
         heartbeat_found = AgentHeartBeat.find_by_instance_id(
             instance_id=instance_id)
         self.assertIsNotNone(heartbeat_found)
-        self.assertEqual(heartbeat.id, heartbeat_found.id)
-        self.assertEqual(heartbeat.instance_id, heartbeat_found.instance_id)
-        self.assertEqual(heartbeat.updated_at, heartbeat_found.updated_at)
-        self.assertEqual(heartbeat.guest_agent_version,
-                         heartbeat_found.guest_agent_version)
+        self.assertEqual(heartbeat_found.id, heartbeat.id)
+        self.assertEqual(heartbeat_found.instance_id, heartbeat.instance_id)
+        self.assertEqual(heartbeat_found.updated_at, heartbeat.updated_at)
+        self.assertEqual(
+            heartbeat_found.guest_agent_version, heartbeat.guest_agent_version)
 
         # update
         AgentHeartBeat().update(id=heartbeat_found.id,
@@ -205,9 +201,9 @@ class AgentHeartBeatTest(trove_testtools.TestCase):
         updated_heartbeat = AgentHeartBeat.find_by_instance_id(
             instance_id=instance_id)
         self.assertIsNotNone(updated_heartbeat)
-        self.assertEqual(heartbeat.id, updated_heartbeat.id)
-        self.assertEqual(heartbeat.instance_id, updated_heartbeat.instance_id)
-        self.assertEqual(heartbeat.guest_agent_version,
-                         updated_heartbeat.guest_agent_version)
+        self.assertEqual(updated_heartbeat.id, heartbeat.id)
+        self.assertEqual(updated_heartbeat.instance_id, heartbeat.instance_id)
+        self.assertEqual(
+            heartbeat_found.guest_agent_version, heartbeat.guest_agent_version)
 
-        self.assertEqual(heartbeat.updated_at, updated_heartbeat.updated_at)
+        self.assertEqual(heartbeat_found.updated_at, heartbeat.updated_at)
