@@ -47,6 +47,7 @@ class GuestAgentCassandraDBManagerTest(testtools.TestCase):
         self.origin_format = volume.VolumeDevice.format
         self.origin_migrate_data = volume.VolumeDevice.migrate_data
         self.origin_mount = volume.VolumeDevice.mount
+        self.origin_mount_points = volume.VolumeDevice.mount_points
         self.origin_stop_db = cass_service.CassandraApp.stop_db
         self.origin_start_db = cass_service.CassandraApp.start_db
         self.origin_install_db = cass_service.CassandraApp._install_db
@@ -62,6 +63,7 @@ class GuestAgentCassandraDBManagerTest(testtools.TestCase):
         volume.VolumeDevice.format = self.origin_format
         volume.VolumeDevice.migrate_data = self.origin_migrate_data
         volume.VolumeDevice.mount = self.origin_mount
+        volume.VolumeDevice.mount_points = self.origin_mount_points
         cass_service.CassandraApp.stop_db = self.origin_stop_db
         cass_service.CassandraApp.start_db = self.origin_start_db
         cass_service.CassandraApp._install_db = self.origin_install_db
@@ -113,10 +115,13 @@ class GuestAgentCassandraDBManagerTest(testtools.TestCase):
         mock_app.write_config = MagicMock(return_value=None)
         mock_app.make_host_reachable = MagicMock(return_value=None)
         mock_app.restart = MagicMock(return_value=None)
+        mock_app.start_db = MagicMock(return_value=None)
+        mock_app.stop_db = MagicMock(return_value=None)
         os.path.exists = MagicMock(return_value=True)
         volume.VolumeDevice.format = MagicMock(return_value=None)
         volume.VolumeDevice.migrate_data = MagicMock(return_value=None)
         volume.VolumeDevice.mount = MagicMock(return_value=None)
+        volume.VolumeDevice.mount_points = MagicMock(return_value=[])
 
         # invocation
         self.manager.prepare(context=self.context, packages=packages,
@@ -126,11 +131,13 @@ class GuestAgentCassandraDBManagerTest(testtools.TestCase):
                              device_path=device_path,
                              mount_point="/var/lib/cassandra",
                              backup_info=backup_info,
-                             overrides=None)
+                             overrides=None,
+                             cluster_config=None)
 
         # verification/assertion
         mock_status.begin_install.assert_any_call()
         mock_app.install_if_needed.assert_any_call(packages)
         mock_app.init_storage_structure.assert_any_call('/var/lib/cassandra')
         mock_app.make_host_reachable.assert_any_call()
-        mock_app.restart.assert_any_call()
+        mock_app.start_db.assert_any_call()
+        mock_app.stop_db.assert_any_call()
