@@ -79,6 +79,9 @@ class FakeAppStatus(BaseDbStatus):
     def set_next_status(self, next_status):
         self.next_fake_status = next_status
 
+    def _is_query_router(self):
+        return False
+
 
 class DbaasTest(testtools.TestCase):
 
@@ -125,12 +128,26 @@ class DbaasTest(testtools.TestCase):
             options = dbaas.load_mysqld_options()
 
         self.assertEqual(5, len(options))
-        self.assertEqual(options["user"], "mysql")
-        self.assertEqual(options["port"], "3306")
-        self.assertEqual(options["basedir"], "/usr")
-        self.assertEqual(options["tmpdir"], "/tmp")
+        self.assertEqual(options["user"], ["mysql"])
+        self.assertEqual(options["port"], ["3306"])
+        self.assertEqual(options["basedir"], ["/usr"])
+        self.assertEqual(options["tmpdir"], ["/tmp"])
         self.assertTrue("skip-external-locking" in options)
 
+    def test_load_mysqld_options_contains_plugin_loads_options(self):
+        output = ("mysqld would've been started with the these args:\n"
+                  "--plugin-load=blackhole=ha_blackhole.so "
+                  "--plugin-load=federated=ha_federated.so")
+
+        with patch.object(os.path, 'isfile', return_value=True):
+            dbaas.utils.execute = Mock(return_value=(output, None))
+            options = dbaas.load_mysqld_options()
+
+        self.assertEqual(1, len(options))
+        self.assertEqual(options["plugin-load"],
+                         ["blackhole=ha_blackhole.so",
+                          "federated=ha_federated.so"])
+
     def test_load_mysqld_options_error(self):
 
         dbaas.utils.execute = Mock(side_effect=ProcessExecutionError())
@@ -219,7 +236,9 @@ class MySqlAdminTest(testtools.TestCase):
                          "Create database queries are not the same")
 
         self.assertEqual(1, dbaas.LocalSqlClient.execute.call_count,
-                         "The client object was not 2 times")
+                         "The client object was not called exactly once, " +
+                         "it was called %d times"
+                         % dbaas.LocalSqlClient.execute.call_count)
 
     def test_create_database_more_than_1(self):
 
@@ -244,7 +263,9 @@ class MySqlAdminTest(testtools.TestCase):
                          "Create database queries are not the same")
 
         self.assertEqual(2, dbaas.LocalSqlClient.execute.call_count,
-                         "The client object was not 2 times")
+                         "The client object was not called exactly twice, " +
+                         "it was called %d times"
+                         % dbaas.LocalSqlClient.execute.call_count)
 
     def test_create_database_no_db(self):
 
@@ -272,7 +293,7 @@ class MySqlAdminTest(testtools.TestCase):
 
     def test_delete_user(self):
 
-        user = {"_name": "testUser"}
+        user = {"_name": "testUser", "_host": None}
 
         self.mySqlAdmin.delete_user(user)
 
@@ -280,7 +301,7 @@ class MySqlAdminTest(testtools.TestCase):
         call_args = dbaas.LocalSqlClient.execute.call_args
         if call_args is not None:
             args, _ = call_args
-            expected = "DROP USER `testUser`;"
+            expected = "DROP USER `testUser`@`%`;"
             self.assertEqual(args[0].text, expected,
                              "Delete user queries are not the same")
 
@@ -469,6 +490,8 @@ class MySqlAppTest(testtools.TestCase):
         super(MySqlAppTest, self).setUp()
         self.orig_utils_execute_with_timeout = dbaas.utils.execute_with_timeout
         self.orig_time_sleep = time.sleep
+        self.orig_unlink = os.unlink
+        self.orig_get_auth_password = dbaas.get_auth_password
         util.init_db()
         self.FAKE_ID = str(uuid4())
         InstanceServiceStatus.create(instance_id=self.FAKE_ID,
@@ -484,11 +507,15 @@ class MySqlAppTest(testtools.TestCase):
         dbaas.operating_system.service_discovery = Mock(return_value=
                                                         mysql_service)
         time.sleep = Mock()
+        os.unlink = Mock()
+        dbaas.get_auth_password = Mock()
 
     def tearDown(self):
         super(MySqlAppTest, self).tearDown()
         dbaas.utils.execute_with_timeout = self.orig_utils_execute_with_timeout
         time.sleep = self.orig_time_sleep
+        os.unlink = self.orig_unlink
+        dbaas.get_auth_password = self.orig_get_auth_password
         InstanceServiceStatus.find_by(instance_id=self.FAKE_ID).delete()
 
     def assert_reported_status(self, expected_status):
@@ -579,13 +606,6 @@ class MySqlAppTest(testtools.TestCase):
         self.assertFalse(self.mySqlApp.start_mysql.called)
         self.assert_reported_status(rd_instance.ServiceStatuses.NEW)
 
-    def test_wipe_ib_logfiles_no_file(self):
-
-        processexecerror = ProcessExecutionError('No such file or directory')
-        dbaas.utils.execute_with_timeout = Mock(side_effect=processexecerror)
-
-        self.mySqlApp.wipe_ib_logfiles()
-
     def test_wipe_ib_logfiles_error(self):
 
         mocked = Mock(side_effect=ProcessExecutionError('Error'))
@@ -666,6 +686,31 @@ class MySqlAppTest(testtools.TestCase):
         dbaas.utils.execute_with_timeout = mocked
         self.assertRaises(ProcessExecutionError, self.mySqlApp.start_mysql)
 
+    def test_mysql_error_in_write_config_verify_unlink(self):
+        configuration = {'config_contents': 'some junk'}
+        from trove.common.exception import ProcessExecutionError
+        dbaas.utils.execute_with_timeout = (
+            Mock(side_effect=ProcessExecutionError('something')))
+
+        self.assertRaises(ProcessExecutionError,
+                          self.mySqlApp.reset_configuration,
+                          configuration=configuration)
+        self.assertEqual(dbaas.utils.execute_with_timeout.call_count, 1)
+        self.assertEqual(os.unlink.call_count, 1)
+        self.assertEqual(dbaas.get_auth_password.call_count, 1)
+
+    def test_mysql_error_in_write_config(self):
+        configuration = {'config_contents': 'some junk'}
+        from trove.common.exception import ProcessExecutionError
+        dbaas.utils.execute_with_timeout = (
+            Mock(side_effect=ProcessExecutionError('something')))
+
+        self.assertRaises(ProcessExecutionError,
+                          self.mySqlApp.reset_configuration,
+                          configuration=configuration)
+        self.assertEqual(dbaas.utils.execute_with_timeout.call_count, 1)
+        self.assertEqual(dbaas.get_auth_password.call_count, 1)
+
 
 class MySqlAppInstallTest(MySqlAppTest):
 
@@ -797,6 +842,29 @@ class MySqlAppMockTest(testtools.TestCase):
                 app.secure('foo', None)
                 self.assertTrue(mock_conn.execute.called)
 
+    def test_secure_with_mycnf_error(self):
+        mock_conn = mock_sql_connection()
+
+        with patch.object(mock_conn, 'execute', return_value=None):
+            operating_system.service_discovery = Mock(return_value={
+                'cmd_stop': 'service mysql stop'})
+            utils.execute_with_timeout = MagicMock(return_value=None)
+            # skip writing the file for now
+            with patch.object(os.path, 'isfile', return_value=False):
+                mock_status = MagicMock()
+                mock_status.wait_for_real_status_to_change_to = MagicMock(
+                    return_value=True)
+                dbaas.clear_expired_password = MagicMock(return_value=None)
+                app = MySqlApp(mock_status)
+                dbaas.clear_expired_password = MagicMock(return_value=None)
+                self.assertRaises(TypeError, app.secure, None, None)
+                self.assertTrue(mock_conn.execute.called)
+                # At least called twice
+                self.assertTrue(mock_conn.execute.call_count >= 2)
+                (mock_status.wait_for_real_status_to_change_to.
+                 assert_called_with(rd_instance.ServiceStatuses.SHUTDOWN,
+                                    app.state_change_wait_time, False))
+
 
 class MySqlRootStatusTest(testtools.TestCase):
 
@@ -1168,7 +1236,7 @@ class MySqlAppStatusTest(testtools.TestCase):
 
         mocked = Mock(side_effect=ProcessExecutionError())
         dbaas.utils.execute_with_timeout = mocked
-        dbaas.load_mysqld_options = Mock()
+        dbaas.load_mysqld_options = Mock(return_value={})
         dbaas.os.path.exists = Mock(return_value=False)
 
         self.mySqlAppStatus = MySqlAppStatus()
@@ -1234,48 +1302,52 @@ class TestRedisApp(testtools.TestCase):
                     self.assertTrue(utils.execute_with_timeout.called)
 
     def test_enable_redis_on_boot_without_upstart(self):
-        with patch.object(os.path, 'isfile', return_value=False):
+        cmd = '123'
+        with patch.object(operating_system, 'service_discovery',
+                          return_value={'cmd_enable': cmd}):
             with patch.object(utils, 'execute_with_timeout',
                               return_value=None):
                 self.app._enable_redis_on_boot()
-                os.path.isfile.assert_any_call(RedisSystem.REDIS_INIT)
+                operating_system.service_discovery.assert_any_call(
+                    RedisSystem.SERVICE_CANDIDATES)
                 utils.execute_with_timeout.assert_any_call(
-                    'sudo ' + RedisSystem.REDIS_CMD_ENABLE,
-                    shell=True)
+                    cmd, shell=True)
 
     def test_enable_redis_on_boot_with_upstart(self):
-        with patch.object(os.path, 'isfile', return_value=True):
+        cmd = '123'
+        with patch.object(operating_system, 'service_discovery',
+                          return_value={'cmd_enable': cmd}):
             with patch.object(utils, 'execute_with_timeout',
                               return_value=None):
                 self.app._enable_redis_on_boot()
-                os.path.isfile.assert_any_call(RedisSystem.REDIS_INIT)
+                operating_system.service_discovery.assert_any_call(
+                    RedisSystem.SERVICE_CANDIDATES)
                 utils.execute_with_timeout.assert_any_call(
-                    "sudo sed -i '/^manual$/d' " + RedisSystem.REDIS_INIT,
-                    shell=True)
+                    cmd, shell=True)
 
     def test_disable_redis_on_boot_with_upstart(self):
-        with patch.object(os.path, 'isfile', return_value=True):
+        cmd = '123'
+        with patch.object(operating_system, 'service_discovery',
+                          return_value={'cmd_disable': cmd}):
             with patch.object(utils, 'execute_with_timeout',
                               return_value=None):
                 self.app._disable_redis_on_boot()
-                os.path.isfile.assert_any_call(RedisSystem.REDIS_INIT)
+                operating_system.service_discovery.assert_any_call(
+                    RedisSystem.SERVICE_CANDIDATES)
                 utils.execute_with_timeout.assert_any_call(
-                    'echo',
-                    "'manual'",
-                    '>>',
-                    RedisSystem.REDIS_INIT,
-                    run_as_root=True,
-                    root_helper='sudo')
+                    cmd, shell=True)
 
     def test_disable_redis_on_boot_without_upstart(self):
-        with patch.object(os.path, 'isfile', return_value=False):
+        cmd = '123'
+        with patch.object(operating_system, 'service_discovery',
+                          return_value={'cmd_disable': cmd}):
             with patch.object(utils, 'execute_with_timeout',
                               return_value=None):
                 self.app._disable_redis_on_boot()
-                os.path.isfile.assert_any_call(RedisSystem.REDIS_INIT)
+                operating_system.service_discovery.assert_any_call(
+                    RedisSystem.SERVICE_CANDIDATES)
                 utils.execute_with_timeout.assert_any_call(
-                    'sudo ' + RedisSystem.REDIS_CMD_DISABLE,
-                    shell=True)
+                    cmd, shell=True)
 
     def test_stop_db_without_fail(self):
         mock_status = MagicMock()
@@ -1374,6 +1446,8 @@ class CassandraDBAppTest(testtools.TestCase):
         self.appStatus = FakeAppStatus(self.FAKE_ID,
                                        rd_instance.ServiceStatuses.NEW)
         self.cassandra = cass_service.CassandraApp(self.appStatus)
+        self.orig_unlink = os.unlink
+        os.unlink = Mock()
 
     def tearDown(self):
 
@@ -1384,6 +1458,7 @@ class CassandraDBAppTest(testtools.TestCase):
         cass_service.packager.pkg_version = self.pkg_version
         cass_service.packager = self.pkg
         InstanceServiceStatus.find_by(instance_id=self.FAKE_ID).delete()
+        os.unlink = self.orig_unlink
 
     def assert_reported_status(self, expected_status):
         service_status = InstanceServiceStatus.find_by(
@@ -1497,6 +1572,29 @@ class CassandraDBAppTest(testtools.TestCase):
 
         self.assert_reported_status(rd_instance.ServiceStatuses.NEW)
 
+    def test_cassandra_error_in_write_config_verify_unlink(self):
+        from trove.common.exception import ProcessExecutionError
+        cass_service.utils.execute_with_timeout = (
+            Mock(side_effect=ProcessExecutionError('some exception')))
+        configuration = 'this is my configuration'
+
+        self.assertRaises(ProcessExecutionError,
+                          self.cassandra.write_config,
+                          config_contents=configuration)
+        self.assertEqual(cass_service.utils.execute_with_timeout.call_count, 1)
+        self.assertEqual(os.unlink.call_count, 1)
+
+    def test_cassandra_error_in_write_config(self):
+        from trove.common.exception import ProcessExecutionError
+        cass_service.utils.execute_with_timeout = (
+            Mock(side_effect=ProcessExecutionError('some exception')))
+        configuration = 'this is my configuration'
+
+        self.assertRaises(ProcessExecutionError,
+                          self.cassandra.write_config,
+                          config_contents=configuration)
+        self.assertEqual(cass_service.utils.execute_with_timeout.call_count, 1)
+
 
 class CouchbaseAppTest(testtools.TestCase):
 
@@ -1591,13 +1689,11 @@ class CouchbaseAppTest(testtools.TestCase):
         self.assertTrue(conductor_api.API.heartbeat.called)
 
     def test_install_when_couchbase_installed(self):
-        self.couchbaseApp.initial_setup = Mock()
         couchservice.packager.pkg_is_installed = Mock(return_value=True)
         couchservice.utils.execute_with_timeout = Mock()
 
         self.couchbaseApp.install_if_needed(["package"])
         self.assertTrue(couchservice.packager.pkg_is_installed.called)
-        self.assertTrue(self.couchbaseApp.initial_setup.called)
         self.assert_reported_status(rd_instance.ServiceStatuses.NEW)
 
 
@@ -1618,6 +1714,7 @@ class MongoDBAppTest(testtools.TestCase):
         self.orig_time_sleep = time.sleep
         self.orig_packager = mongo_system.PACKAGER
         self.orig_service_discovery = operating_system.service_discovery
+        self.orig_os_unlink = os.unlink
 
         operating_system.service_discovery = (
             self.fake_mongodb_service_discovery)
@@ -1629,6 +1726,7 @@ class MongoDBAppTest(testtools.TestCase):
                                        rd_instance.ServiceStatuses.NEW)
         self.mongoDbApp = mongo_service.MongoDBApp(self.appStatus)
         time.sleep = Mock()
+        os.unlink = Mock()
 
     def tearDown(self):
         super(MongoDBAppTest, self).tearDown()
@@ -1637,6 +1735,7 @@ class MongoDBAppTest(testtools.TestCase):
         time.sleep = self.orig_time_sleep
         mongo_system.PACKAGER = self.orig_packager
         operating_system.service_discovery = self.orig_service_discovery
+        os.unlink = self.orig_os_unlink
         InstanceServiceStatus.find_by(instance_id=self.FAKE_ID).delete()
 
     def assert_reported_status(self, expected_status):
@@ -1724,6 +1823,31 @@ class MongoDBAppTest(testtools.TestCase):
 
         self.assertRaises(RuntimeError, self.mongoDbApp.start_db)
 
+    def test_mongodb_error_in_write_config_verify_unlink(self):
+        configuration = {'config_contents': 'some junk'}
+        from trove.common.exception import ProcessExecutionError
+        mongo_service.utils.execute_with_timeout = (
+            Mock(side_effect=ProcessExecutionError('some exception')))
+
+        self.assertRaises(ProcessExecutionError,
+                          self.mongoDbApp.reset_configuration,
+                          configuration=configuration)
+        self.assertEqual(
+            mongo_service.utils.execute_with_timeout.call_count, 1)
+        self.assertEqual(os.unlink.call_count, 1)
+
+    def test_mongodb_error_in_write_config(self):
+        configuration = {'config_contents': 'some junk'}
+        from trove.common.exception import ProcessExecutionError
+        mongo_service.utils.execute_with_timeout = (
+            Mock(side_effect=ProcessExecutionError('some exception')))
+
+        self.assertRaises(ProcessExecutionError,
+                          self.mongoDbApp.reset_configuration,
+                          configuration=configuration)
+        self.assertEqual(
+            mongo_service.utils.execute_with_timeout.call_count, 1)
+
     def test_start_db_with_conf_changes_db_is_running(self):
 
         self.mongoDbApp.start_db = Mock()
